@@ -29,11 +29,11 @@
 #include "exportdialog.h"
 #include "qetgraphicsitem/ghostelement.h"
 #include "qetgraphicsitem/independenttextitem.h"
-#include "qetapp.h"
 #include "qetgraphicsitem/diagramimageitem.h"
 #include "qetgraphicsitem/qetshapeitem.h"
 #include "terminal.h"
 #include "elementtextsmover.h"
+#include "diagrameventinterface.h"
 
 const int   Diagram::xGrid  = 10;
 const int   Diagram::yGrid  = 10;
@@ -54,19 +54,18 @@ Diagram::Diagram(QETProject *project) :
 	draw_grid_               (true),
 	use_border_              (true),
 	draw_terminals_          (true),
-	draw_colored_conductors_ (true)
+	draw_colored_conductors_ (true),
+	m_event_interface (nullptr)
 {
 	setProject(project);
 	qgi_manager_ = new QGIManager(this);
 	setBackgroundBrush(Qt::white);
-	conductor_setter_ = new QGraphicsLineItem(0, 0);
+	conductor_setter_ = new QGraphicsLineItem(0);
 	conductor_setter_ -> setZValue(1000000);
-	QPen t;
-	t.setColor(Qt::black);
-	t.setWidthF(1.5);
-	t.setStyle(Qt::DashLine);
-	conductor_setter_ -> setPen(t);
-	conductor_setter_ -> setLine(QLineF(QPointF(0.0, 0.0), QPointF(0.0, 0.0)));
+
+	QPen pen(Qt::NoBrush, 1.5, Qt::DashLine);
+	pen.setColor(Qt::black);
+	conductor_setter_ -> setPen(pen);
 	
 		//Init object for manage movement
 	elements_mover_      = new ElementsMover();
@@ -74,6 +73,8 @@ Diagram::Diagram(QETProject *project) :
 
 	connect(&border_and_titleblock, SIGNAL(needTitleBlockTemplate(const QString &)), this, SLOT(setTitleBlockTemplate(const QString &)));
 	connect(&border_and_titleblock, SIGNAL(diagramTitleChanged(const QString &)),    this, SLOT(titleChanged(const QString &)));
+	connect(&border_and_titleblock, SIGNAL(borderChanged(QRectF,QRectF)), this, SLOT(adjustSceneRect()));
+	adjustSceneRect();
 }
 
 /**
@@ -91,6 +92,8 @@ Diagram::~Diagram() {
 	// delete of object for manage movement
 	delete elements_mover_;
 	delete element_texts_mover_;
+
+	if (m_event_interface) delete m_event_interface;
 	
 	// list removable items
 	QList<QGraphicsItem *> deletable_items;
@@ -123,19 +126,27 @@ void Diagram::drawBackground(QPainter *p, const QRectF &r) {
 	p -> drawRect(r);
 	
 	if (draw_grid_) {
-		// dessine les points de la grille
-		// if background color is black, then grid spots shall be white, else they shall be black in color.
-		if (Diagram::background_color == Qt::black)
-			p -> setPen(Qt::white);
-		else
-			p -> setPen(Qt::black);
+			//Draw the point of the grid
+			// if background color is black, then grid spots shall be white, else they shall be black in color.
+		QPen pen;
+		Diagram::background_color == Qt::black? pen.setColor(Qt::white) : pen.setColor(Qt::black);
+		pen.setCosmetic(true);
+		p->setPen(pen);
+
 		p -> setBrush(Qt::NoBrush);
-		qreal limite_x = r.x() + r.width();
-		qreal limite_y = r.y() + r.height();
+
+			//If user allow zoom out beyond of folio, we draw grid outside of border.
+		QSettings settings;
+		QRectF rect = settings.value("diagrameditor/zoom-out-beyond-of-folio", false).toBool() ?
+						  r :
+						  border_and_titleblock.insideBorderRect().intersected(r);
+
+		qreal limite_x = rect.x() + rect.width();
+		qreal limite_y = rect.y() + rect.height();
 		
-		int g_x = (int)ceil(r.x());
+		int g_x = (int)ceil(rect.x());
 		while (g_x % xGrid) ++ g_x;
-		int g_y = (int)ceil(r.y());
+		int g_y = (int)ceil(rect.y());
 		while (g_y % yGrid) ++ g_y;
 		
 		QPolygon points;
@@ -147,15 +158,80 @@ void Diagram::drawBackground(QPainter *p, const QRectF &r) {
 		p -> drawPoints(points);
 	}
 	
-	if (use_border_) border_and_titleblock.draw(p, margin, margin);
+	if (use_border_) border_and_titleblock.draw(p);
 	p -> restore();
 }
 
 /**
-	Gere les enfoncements de touches du clavier
-	@param e QKeyEvent decrivant l'evenement clavier
-*/
-void Diagram::keyPressEvent(QKeyEvent *e) {
+ * @brief Diagram::mouseDoubleClickEvent
+ * This event is managed by diagram event interface if any.
+ * @param event :
+ */
+void Diagram::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
+{
+	if (m_event_interface && m_event_interface->mouseDoubleClickEvent(event)) return;
+
+	QGraphicsScene::mouseDoubleClickEvent(event);
+}
+
+/**
+ * @brief Diagram::mousePressEvent
+ * This event is managed by diagram event interface if any.
+ * @param event
+ */
+void Diagram::mousePressEvent(QGraphicsSceneMouseEvent *event)
+{
+	if (m_event_interface && m_event_interface->mousePressEvent(event)) return;
+
+	QGraphicsScene::mousePressEvent(event);
+}
+
+/**
+ * @brief Diagram::mouseMoveEvent
+ * This event is managed by diagram event interface if any.
+ * @param event
+ */
+void Diagram::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
+{
+	if (m_event_interface && m_event_interface->mouseMoveEvent(event)) return;
+
+	QGraphicsScene::mouseMoveEvent(event);
+}
+
+/**
+ * @brief Diagram::mouseReleaseEvent
+ * This event is managed by diagram event interface if any.
+ * @param event
+ */
+void Diagram::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
+{
+	if (m_event_interface && m_event_interface->mouseReleaseEvent(event)) return;
+
+	QGraphicsScene::mouseReleaseEvent(event);
+}
+
+/**
+ * @brief Diagram::wheelEvent
+ * This event is managed by diagram event interface if any.
+ * @param event
+ */
+void Diagram::wheelEvent(QGraphicsSceneWheelEvent *event)
+{
+	if (m_event_interface && m_event_interface->wheelEvent(event)) return;
+
+	QGraphicsScene::wheelEvent(event);
+}
+
+/**
+ * @brief Diagram::keyPressEvent
+ * This event is managed by diagram event interface if any.
+ * Else move selected elements
+ * @param e
+ */
+void Diagram::keyPressEvent(QKeyEvent *e)
+{
+	if (m_event_interface && m_event_interface->keyPressEvent(e)) return;
+
 	bool transmit_event = true;
 	if (!isReadOnly()) {
 		QPointF movement;
@@ -178,10 +254,15 @@ void Diagram::keyPressEvent(QKeyEvent *e) {
 }
 
 /**
-	Gere les relachements de touches du clavier
-	@param e QKeyEvent decrivant l'evenement clavier
-*/
-void Diagram::keyReleaseEvent(QKeyEvent *e) {
+ * @brief Diagram::keyReleaseEvent
+ * This event is managed by diagram event interface if any.
+ * Else move selected element
+ * @param e
+ */
+void Diagram::keyReleaseEvent(QKeyEvent *e)
+{
+	if (m_event_interface && m_event_interface->KeyReleaseEvent(e)) return;
+
 	bool transmit_event = true;
 	if (!isReadOnly()) {
 		// detecte le relachement d'une touche de direction ( = deplacement d'elements)
@@ -200,6 +281,27 @@ void Diagram::keyReleaseEvent(QKeyEvent *e) {
 	}
 }
 
+/**
+ * @brief Diagram::setEventInterface
+ * Set event_interface has current interface.
+ * Diagram become the ownership of event_interface
+ * If there is a previous interface, they will be delete before
+ * and call init() to the new interface.
+ * The derivated class of DiagramEventInterface need to emit the signal "finish" when the job is done,
+ * diagram use this signal to delete the interface. If the signal isn't send, the interface will never be deleted.
+ * @param event_interface
+ */
+void Diagram::setEventInterface(DiagramEventInterface *event_interface)
+{
+	if (m_event_interface)
+	{
+		delete m_event_interface;
+		event_interface -> init();
+	}
+	m_event_interface = event_interface;
+	connect (m_event_interface, &DiagramEventInterface::finish, this, [this]() { delete this->m_event_interface; this->m_event_interface = nullptr;}, Qt::QueuedConnection);
+}
+
 /**
  * @brief Diagram::conductorsAutonumName
  * @return the name of autonum to use.
@@ -232,8 +334,8 @@ bool Diagram::toPaintDevice(QPaintDevice &pix, int width, int height, Qt::Aspect
 		source_area = QRectF(
 			0.0,
 			0.0,
-			border_and_titleblock.borderWidth () + 2.0 * margin,
-			border_and_titleblock.borderHeight() + 2.0 * margin
+			border_and_titleblock.borderAndTitleBlockRect().width()  + 2.0 * margin,
+			border_and_titleblock.borderAndTitleBlockRect().height() + 2.0 * margin
 		);
 	}
 	
@@ -275,8 +377,8 @@ QSize Diagram::imageSize() const {
 		image_width  = items_rect.width();
 		image_height = items_rect.height();
 	} else {
-		image_width  = border_and_titleblock.borderWidth();
-		image_height = border_and_titleblock.borderHeight();
+		image_width  = border_and_titleblock.borderAndTitleBlockRect().width();
+		image_height = border_and_titleblock.borderAndTitleBlockRect().height();
 	}
 	
 	image_width  += 2.0 * margin;
@@ -539,10 +641,11 @@ bool Diagram::fromXml(QDomElement &document, QPointF position, bool consider_inf
 		project_ -> state() == QETProject::ProjectParsingRunning
 	);
 	
-	// chargement de tous les elements du fichier XML
+		//Load all elements from the XML
 	QList<Element *> added_elements;
 	QHash<int, Terminal *> table_adr_id;
-	foreach (QDomElement element_xml, QET::findInDomElement(root, "elements", "element")) {
+	foreach (QDomElement element_xml, QET::findInDomElement(root, "elements", "element"))
+	{
 		if (!Element::valideXml(element_xml)) continue;
 		
 		// cree un element dont le type correspond a l'id type
@@ -552,7 +655,8 @@ bool Diagram::fromXml(QDomElement &document, QPointF position, bool consider_inf
 		
 		int state = 0;
 		Element *nvel_elmt = ElementFactory::Instance() -> createElement(element_location, 0, &state);
-		if (state) {
+		if (state)
+		{
 			QString debug_message = QString("Diagram::fromXml() : Le chargement de la description de l'element %1 a echoue avec le code d'erreur %2").arg(element_location.path()).arg(state);
 			qDebug() << qPrintable(debug_message);
 			delete nvel_elmt;
@@ -614,10 +718,15 @@ bool Diagram::fromXml(QDomElement &document, QPointF position, bool consider_inf
 			Terminal *p2 = table_adr_id.value(id_p2);
 			if (p1 != p2)
 			{
-				Conductor *c = new Conductor(table_adr_id.value(id_p1), table_adr_id.value(id_p2));
-				addItem(c);
-				c -> fromXml(f);
-				added_conductors << c;
+				Conductor *c = new Conductor(p1, p2);
+				if (c->isValid())
+				{
+					addItem(c);
+					c -> fromXml(f);
+					added_conductors << c;
+				}
+				else
+					delete c;
 			}
 		}
 		else qDebug() << "Diagram::fromXml() : Le chargement du conducteur" << id_p1 << id_p2 << "a echoue";
@@ -656,7 +765,7 @@ bool Diagram::fromXml(QDomElement &document, QPointF position, bool consider_inf
 		content_ptr -> images			= added_images.toSet();
 		content_ptr -> shapes			= added_shapes.toSet();
 	}
-	
+	adjustSceneRect();
 	return(true);
 }
 
@@ -664,8 +773,9 @@ bool Diagram::fromXml(QDomElement &document, QPointF position, bool consider_inf
 	Enregistre le schema XML dans son document XML interne et emet le signal
 	written().
 */
-void Diagram::write() {
-	qDebug() << qPrintable(QString("Diagram::write() : saving changes from diagram \"%1\" [%2]").arg(title()).arg(QET::pointerString(this)));
+void Diagram::write()
+{
+	qDebug() << qPrintable(QString("Diagram::write() : saving changes from diagram \"%1\"").arg(title())) << "[" << this << "]";
 	write(toXml().documentElement());
 }
 
@@ -708,131 +818,78 @@ void Diagram::initElementsLinks() {
 
 /**
  * @brief Diagram::addItem
- * Add element to diagram
- * @param element
- */
-void Diagram::addItem(Element *element) {
-	if (!element || isReadOnly()) return;
-
-	if (element -> scene() != this)
-		QGraphicsScene::addItem(element);
-	foreach(ElementTextItem *eti, element -> texts()) {
-		connect(
-			eti,
-			SIGNAL(diagramTextChanged(DiagramTextItem *, const QString &, const QString &)),
-			this,
-			SLOT(diagramTextChanged(DiagramTextItem *, const QString &, const QString &))
-		);
-	}
-}
-
-/**
- * @brief Diagram::addItem
- * Add conductor to scene.
- * @param conductor
- */
-void Diagram::addItem(Conductor *conductor) {
-	if (!conductor || isReadOnly()) return;
-	
-	if (conductor -> scene() != this) {
-		QGraphicsScene::addItem(conductor);
-		conductor -> terminal1 -> addConductor(conductor);
-		conductor -> terminal2 -> addConductor(conductor);
-		conductor -> calculateTextItemPosition();
-	}
-}
-
-/**
- * @brief Diagram::addItem
- * Add text item to diagram
- * @param iti
- */
-void Diagram::addItem(IndependentTextItem *iti) {
-	if (!iti || isReadOnly()) return;
-	
-	if (iti -> scene() != this)
-		QGraphicsScene::addItem(iti);
-	
-	connect(
-		iti,
-		SIGNAL(diagramTextChanged(DiagramTextItem *, const QString &, const QString &)),
-		this,
-		SLOT(diagramTextChanged(DiagramTextItem *, const QString &, const QString &))
-	);
-}
-
-/**
- * @brief Diagram::addItem
- * Generique method to add item to scene
+ * Réimplemented from QGraphicsScene::addItem(QGraphicsItem *item)
+ * Do some specific operation if item need it (for exemple an element)
  * @param item
  */
-void Diagram::addItem(QGraphicsItem *item) {
+void Diagram::addItem(QGraphicsItem *item)
+{
+	if (!item || isReadOnly() || item->scene() == this) return;
+	QGraphicsScene::addItem(item);
+
+	switch (item->type())
+	{
+		case Element::Type:
+		{
+			const Element *elmt = static_cast<const Element*>(item);
+			foreach(ElementTextItem *eti, elmt->texts())
+				connect (eti, &ElementTextItem::diagramTextChanged, this, &Diagram::diagramTextChanged);
+		}
+			break;
+
+		case Conductor::Type:
+		{
+			Conductor *conductor = static_cast<Conductor *>(item);
+			conductor->terminal1->addConductor(conductor);
+			conductor->terminal2->addConductor(conductor);
+			conductor->calculateTextItemPosition();
+		}
+			break;
+
+		case IndependentTextItem::Type:
+		{
+			const IndependentTextItem *text = static_cast<const IndependentTextItem *>(item);
+			connect(text, &IndependentTextItem::diagramTextChanged, this, &Diagram::diagramTextChanged);
+		}
+	}
+}
+
+/**
+ * @brief Diagram::removeItem
+ * Réimplemented from QGraphicsScene::removeItem(QGraphicsItem *item)
+ * Do some specific operation if item need it (for exemple an element)
+ * @param item
+ */
+void Diagram::removeItem(QGraphicsItem *item)
+{
 	if (!item || isReadOnly()) return;
-	if (item -> scene() != this)
-		QGraphicsScene::addItem(item);
-}
 
-/**
- * @brief Diagram::removeItem
- * Remove an element from the scene
- * @param element
- */
-void Diagram::removeItem(Element *element) {
-	if (!element || isReadOnly()) return;
+	switch (item->type())
+	{
+		case Element::Type:
+		{
+			Element *elmt = static_cast<Element *>(item);
+			elmt->unlinkAllElements();
+			foreach(ElementTextItem *text, elmt->texts())
+				disconnect(text, &ElementTextItem::diagramTextChanged, this, &Diagram::diagramTextChanged);
+		}
+			break;
 
-	// remove all links of element
-	element->unlinkAllElements();
+		case Conductor::Type:
+		{
+			Conductor *conductor = static_cast<Conductor *>(item);
+			conductor->terminal1->removeConductor(conductor);
+			conductor->terminal2->removeConductor(conductor);
+		}
+			break;
 
-	QGraphicsScene::removeItem(element);
-
-	foreach(ElementTextItem *eti, element -> texts()) {
-		disconnect(
-			eti,
-			SIGNAL(diagramTextChanged(DiagramTextItem *, const QString &, const QString &)),
-			this,
-			SLOT(diagramTextChanged(DiagramTextItem *, const QString &, const QString &))
-		);
+		case IndependentTextItem::Type:
+		{
+			const IndependentTextItem *text = static_cast<const IndependentTextItem *>(item);
+			disconnect(text, &IndependentTextItem::diagramTextChanged, this, &Diagram::diagramTextChanged);
+		}
 	}
-}
 
-/**
- * @brief Diagram::removeItem
- * Remove a conductor from diagram
- * @param conductor
- */
-void Diagram::removeItem(Conductor *conductor) {
-	if (!conductor || isReadOnly()) return;
-
-	conductor -> terminal1 -> removeConductor(conductor);
-	conductor -> terminal2 -> removeConductor(conductor);
-
-	QGraphicsScene::removeItem(conductor);
-}
-
-/**
- * @brief Diagram::removeItem
- * Remove text field from diagram
- * @param iti
- */
-void Diagram::removeItem(IndependentTextItem *iti) {
-	if (!iti || isReadOnly()) return;
-	
-	QGraphicsScene::removeItem(iti);
-
-	disconnect(
-		iti,
-		SIGNAL(diagramTextChanged(DiagramTextItem *, const QString &, const QString &)),
-		this,
-		SLOT(diagramTextChanged(DiagramTextItem *, const QString &, const QString &))
-	);
-}
-
-/**
- * @brief Diagram::removeItem
- * Generique methode to remove QGraphicsItem from diagram
- * @param item
- */
-void Diagram::removeItem(QGraphicsItem *item) {
 	QGraphicsScene::removeItem(item);
 }
 
@@ -872,10 +929,10 @@ void Diagram::titleBlockTemplateChanged(const QString &template_name) {
 	@param template_name Name of the title block template that has changed
 	@param new_template (Optional) Name of the title block template to use instead
 */
-void Diagram::titleBlockTemplateRemoved(const QString &template_name, const QString &new_template) {
-	if (border_and_titleblock.titleBlockTemplateName() != template_name) return;
-	
-	const TitleBlockTemplate *final_template = project_ -> getTemplateByName(new_template);
+void Diagram::titleBlockTemplateRemoved(const QString &template_name, const QString &new_template)
+{
+	if (border_and_titleblock.titleBlockTemplateName() != template_name) return;	
+	const TitleBlockTemplate *final_template = project_->embeddedTitleBlockTemplatesCollection()->getTemplate(new_template);
 	border_and_titleblock.titleBlockTemplateRemoved(template_name, final_template);
 	update();
 }
@@ -884,16 +941,16 @@ void Diagram::titleBlockTemplateRemoved(const QString &template_name, const QStr
 	Set the template to use to render the title block of this diagram.
 	@param template_name Name of the title block template.
 */
-void Diagram::setTitleBlockTemplate(const QString &template_name) {
+void Diagram::setTitleBlockTemplate(const QString &template_name)
+{
 	if (!project_) return;
 	
 	QString current_name = border_and_titleblock.titleBlockTemplateName();
-	const TitleBlockTemplate *titleblock_template = project_ -> getTemplateByName(template_name);
+	const TitleBlockTemplate *titleblock_template = project_->embeddedTitleBlockTemplatesCollection()->getTemplate(template_name);
 	border_and_titleblock.titleBlockTemplateRemoved(current_name, titleblock_template);
 	
-	if (template_name != current_name) {
+	if (template_name != current_name)
 		emit(usedTitleBlockTemplateChanged(template_name));
-	}
 }
 
 /**
@@ -929,49 +986,6 @@ void Diagram::invertSelection() {
 	emit(selectionChanged());
 }
 
-/**
- * @brief Diagram::border
- * @return The rectangle (coordinates relative to the scene)
- * delimiting the edge of the diagram
- */
-QRectF Diagram::border() const
-{
-	return(
-		QRectF(
-			margin,
-			margin,
-			border_and_titleblock.borderWidth(),
-			border_and_titleblock.borderHeight()
-		)
-	);
-}
-
-/**
- * @brief Diagram::drawingRect
- * @return The rectangle (coordinates relative to the scene)
- * delimiting the drawing area of the diagram.
- * It's like border without columns, rows, and titleblock
- */
-QRectF Diagram::drawingRect() const
-{
-	QPointF topleft(margin, margin);
-	QSizeF size;
-	size.setWidth (border_and_titleblock.columnsTotalWidth());
-	size.setHeight(border_and_titleblock.rowsTotalHeight());
-
-	if (border_and_titleblock.rowsAreDisplayed())
-		topleft.rx() += border_and_titleblock.rowsHeaderWidth();
-	else
-		size.rwidth() += border_and_titleblock.rowsHeaderWidth();
-
-	if (border_and_titleblock.columnsAreDisplayed())
-		topleft.ry() += border_and_titleblock.columnsHeaderHeight();
-	else
-		size.rheight() += border_and_titleblock.columnsHeaderHeight();
-
-	return (QRectF (topleft, size));
-}
-
 /**
 	@return le titre du cartouche
 */
@@ -1080,6 +1094,17 @@ bool Diagram::usesTitleBlockTemplate(const QString &name) {
 	return(name == border_and_titleblock.titleBlockTemplateName());
 }
 
+/**
+ * @brief Diagram::adjustSceneRect
+ * Recalcul and adjust the size of the scene
+ */
+void Diagram::adjustSceneRect()
+{
+	QRectF old_rect = sceneRect();
+	setSceneRect(border_and_titleblock.borderAndTitleBlockRect().united(itemsBoundingRect()));
+	update(old_rect.united(sceneRect()));
+}
+
 /**
 	Cette methode permet d'appliquer de nouvelles options de rendu tout en
 	accedant aux proprietes de rendu en cours.
@@ -1114,11 +1139,8 @@ ExportProperties Diagram::applyProperties(const ExportProperties &new_properties
 	@return la position dans la grille correspondant a pos
 */
 DiagramPosition Diagram::convertPosition(const QPointF &pos) {
-	// decale la position pour prendre en compte les marges en haut a gauche du schema
-	QPointF final_pos = pos - QPointF(margin, margin);
-	
 	// delegue le calcul au BorderTitleBlock
-	DiagramPosition diagram_position = border_and_titleblock.convertPosition(final_pos);
+	DiagramPosition diagram_position = border_and_titleblock.convertPosition(pos);
 	
 	// embarque la position cartesienne
 	diagram_position.setPosition(pos);
