@@ -42,6 +42,8 @@
 #include "factory/elementfactory.h"
 #include "diagrampropertiesdialog.h"
 #include "dveventinterface.h"
+#include "diagrameventaddelement.h"
+#include "QPropertyUndoCommand/qpropertyundocommand.h"
 
 /**
 	Constructeur
@@ -51,16 +53,17 @@
 DiagramView::DiagramView(Diagram *diagram, QWidget *parent) :
 	QGraphicsView     (parent),
 	scene             (diagram),
-	m_event_interface (nullptr)
+	m_event_interface (nullptr),
+	m_first_activation (true)
 {
 	grabGesture(Qt::PinchGesture);
 	setAttribute(Qt::WA_DeleteOnClose, true);
 	setInteractive(true);
 
 	QString whatsthis = tr(
-		"Ceci est la zone dans laquelle vous concevez vos sch\351mas en y ajoutant"
-		" des \351l\351ments et en posant des conducteurs entre leurs bornes. Il est"
-		" \351galement possible d'ajouter des textes ind\351pendants.",
+		"Ceci est la zone dans laquelle vous concevez vos schémas en y ajoutant"
+		" des éléments et en posant des conducteurs entre leurs bornes. Il est"
+		" également possible d'ajouter des textes indépendants.",
 		"\"What's this?\" tip"
 	);
 	setWhatsThis(whatsthis);
@@ -86,13 +89,11 @@ DiagramView::DiagramView(Diagram *diagram, QWidget *parent) :
 	
 	connect(scene, SIGNAL(showDiagram(Diagram*)), this, SIGNAL(showDiagram(Diagram*)));
 	connect(scene, SIGNAL(selectionChanged()), this, SIGNAL(selectionChanged()));
-	connect(&(scene -> border_and_titleblock), SIGNAL(borderChanged(QRectF, QRectF)), this, SLOT(adjustSceneRect()));
-	connect(&(scene -> border_and_titleblock), SIGNAL(displayChanged()),              this, SLOT(adjustSceneRect()));
+	connect(scene, SIGNAL(sceneRectChanged(QRectF)), this, SLOT(adjustSceneRect()));
 	connect(&(scene -> border_and_titleblock), SIGNAL(diagramTitleChanged(const QString &)), this, SLOT(updateWindowTitle()));
 	connect(diagram, SIGNAL(editElementRequired(ElementsLocation)), this, SIGNAL(editElementRequired(ElementsLocation)));
 	connect(diagram, SIGNAL(findElementRequired(ElementsLocation)), this, SIGNAL(findElementRequired(ElementsLocation)));
 	
-	connect(this, SIGNAL(aboutToAddElement()), this, SLOT(addDroppedElement()), Qt::QueuedConnection);
 	connect(
 		this, SIGNAL(aboutToSetDroppedTitleBlockTemplate(const TitleBlockTemplateLocation &)),
 		this, SLOT(setDroppedTitleBlockTemplate(const TitleBlockTemplateLocation &)),
@@ -194,10 +195,10 @@ void DiagramView::rotateTexts() {
 	// demande un angle a l'utilisateur
 	QDialog ori_text_dialog(diagramEditor());
 	ori_text_dialog.setSizeGripEnabled(false);
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 	ori_text_dialog.setWindowFlags(Qt::Sheet);
 #endif
-	ori_text_dialog.setWindowTitle(tr("Orienter les textes s\351lectionn\351s", "window title"));
+	ori_text_dialog.setWindowTitle(tr("Orienter les textes sélectionnés", "window title"));
 // 	ori_text_dialog.setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
 	
 	
@@ -243,7 +244,7 @@ void DiagramView::dragEnterEvent(QDragEnterEvent *e) {
 }
 
 /**
-	Gere les dragleaveevent
+	Gere les dragleave
 	@param e le QDragEnterEvent correspondant au drag'n drop sortant
 */
 void DiagramView::dragLeaveEvent(QDragLeaveEvent *e) {
@@ -287,11 +288,10 @@ void DiagramView::handleElementDrop(QDropEvent *e) {
 	// verifie qu'il existe un element correspondant a cet emplacement
 	ElementsCollectionItem *dropped_item = QETApp::collectionItem(location);
 	if (!dropped_item) return;
-	
-	next_location_ = location;
-	next_position_ = e-> pos();
-	
-	emit(aboutToAddElement());
+
+	diagram()->setEventInterface(new DiagramEventAddElement(location, diagram(), mapToScene(e->pos())));
+		//Set focus to the view to get event
+	this->setFocus();
 }
 
 /**
@@ -345,40 +345,22 @@ void DiagramView::setSelectionMode() {
 }
 
 /**
-	Agrandit le schema (+33% = inverse des -25 % de zoomMoins())
-*/
-void DiagramView::zoomIn() {
-	scale(4.0/3.0, 4.0/3.0);
-	adjustGridToZoom();
-}
-
-/**
-	Retrecit le schema (-25% = inverse des +33 % de zoomPlus())
-*/
-void DiagramView::zoomOut() {
-	scale(0.75, 0.75);
-	if ((mapFromScene(0,0).rx() == 0) && (mapFromScene(0,0).ry() == 0)){
-		fitInView(sceneRect(), Qt::KeepAspectRatio);
-	}
-	adjustGridToZoom();
-}
-
-/**
-	Agrandit le schema avec le trackpad
-*/
-void DiagramView::zoomInSlowly() {
-	scale(1.02, 1.02);
-	adjustGridToZoom();
-}
-
-/**
-	Retrecit le schema avec le trackpad
-*/
-void DiagramView::zoomOutSlowly() {
-	scale(0.98, 0.98);
-	// Interdit le dezoome plus grand que le schéma
-	if ((mapFromScene(0,0).rx() == 0) && (mapFromScene(0,0).ry() == 0)){
-		fitInView(sceneRect(), Qt::KeepAspectRatio);
+ * @brief DiagramView::zoom
+ * Zomm the view.
+ * A zoom_factor > 1 zoom in.
+ * A zoom_factor < 1 zoom out
+ * @param zoom_factor
+ */
+void DiagramView::zoom(const qreal zoom_factor)
+{
+	if (zoom_factor >= 1)
+		scale(zoom_factor, zoom_factor);
+	else
+	{
+		QSettings settings;
+		if (settings.value("diagrameditor/zoom-out-beyond-of-folio", false).toBool() ||
+			(horizontalScrollBar()->maximum() || verticalScrollBar()->maximum()) )
+			scale(zoom_factor, zoom_factor);
 	}
 	adjustGridToZoom();
 }
@@ -390,7 +372,7 @@ void DiagramView::zoomOutSlowly() {
 */
 void DiagramView::zoomFit() {
 	adjustSceneRect();
-	fitInView(sceneRect(), Qt::KeepAspectRatio);
+	fitInView(scene->sceneRect(), Qt::KeepAspectRatio);
 	adjustGridToZoom();
 }
 
@@ -465,31 +447,24 @@ void DiagramView::pasteHere() {
 }
 
 /**
-	Manage the events press click mouse :
+	Manage the events press click :
 	 *  click to add an independent text field
 */
-void DiagramView::mousePressEvent(QMouseEvent *e) {
-
-	if (fresh_focus_in_) {
+void DiagramView::mousePressEvent(QMouseEvent *e)
+{
+	if (fresh_focus_in_)
+	{
 		switchToVisualisationModeIfNeeded(e);
 		fresh_focus_in_ = false;
 	}
 
-	if (m_event_interface) {
-		if (m_event_interface -> mousePressEvent(e)) {
-			if (m_event_interface->isFinish()) {
-				emit (itemAdded());
-				delete m_event_interface; m_event_interface = nullptr;
-			}
-			return;
-		}
-	}
+	if (m_event_interface && m_event_interface->mousePressEvent(e)) return;
 
-	//Start drag view when hold the middle button
-	if (e -> button() == Qt::MidButton) {
-		rubber_band_origin = mapToScene(e -> pos());
-		setCursor(Qt::ClosedHandCursor);
-		center_view_ = mapToScene(this -> viewport() -> rect().center());
+		//Start drag view when hold the middle button
+	if (e->button() == Qt::MidButton)
+	{
+		rubber_band_origin = e->pos();
+		viewport()->setCursor(Qt::ClosedHandCursor);
 	}
 
 	else QGraphicsView::mousePressEvent(e);
@@ -499,22 +474,19 @@ void DiagramView::mousePressEvent(QMouseEvent *e) {
  * @brief DiagramView::mouseMoveEvent
  * Manage the event move mouse
  */
-void DiagramView::mouseMoveEvent(QMouseEvent *e) {
+void DiagramView::mouseMoveEvent(QMouseEvent *e)
+{
+	if (m_event_interface && m_event_interface->mouseMoveEvent(e)) return;
 
-	if (m_event_interface) {
-		if (m_event_interface -> mouseMoveEvent(e)) {
-			if (m_event_interface->isFinish()) {
-				emit (itemAdded());
-				delete m_event_interface; m_event_interface = nullptr;
-			}
-			return;
-		}
-	}
-	//Drag the view
-	if (e -> buttons() == Qt::MidButton) {
-		QPointF move = rubber_band_origin - mapToScene(e -> pos());
-		this -> centerOn(center_view_ + move);
-		center_view_ = mapToScene( this -> viewport() -> rect().center() );
+		//Drag the view
+	if (e->buttons() == Qt::MidButton)
+	{
+		QScrollBar *h = horizontalScrollBar();
+		QScrollBar *v = verticalScrollBar();
+		QPointF pos = rubber_band_origin - e -> pos();
+		rubber_band_origin = e -> pos();
+		h -> setValue(h -> value() + pos.x());
+		v -> setValue(v -> value() + pos.y());
 	}
 
 	else QGraphicsView::mouseMoveEvent(e);
@@ -524,19 +496,12 @@ void DiagramView::mouseMoveEvent(QMouseEvent *e) {
  * @brief DiagramView::mouseReleaseEvent
  * Manage event release click mouse
  */
-void DiagramView::mouseReleaseEvent(QMouseEvent *e) {
+void DiagramView::mouseReleaseEvent(QMouseEvent *e)
+{
+	if (m_event_interface && m_event_interface->mouseReleaseEvent(e)) return;
 
-	if (m_event_interface) {
-		if (m_event_interface -> mouseReleaseEvent(e)) {
-			if (m_event_interface->isFinish()) {
-				emit (itemAdded());
-				delete m_event_interface; m_event_interface = nullptr;
-			}
-			return;
-		}
-	}
 	//Stop drag view
-	if (e -> button() == Qt::MidButton) setCursor(Qt::ArrowCursor);
+	if (e -> button() == Qt::MidButton) viewport()->setCursor(Qt::ArrowCursor);
 
 	else QGraphicsView::mouseReleaseEvent(e);
 }
@@ -545,55 +510,60 @@ void DiagramView::mouseReleaseEvent(QMouseEvent *e) {
  * @brief DiagramView::gestures
  * @return
  */
-bool DiagramView::gestures() const {
-	return(QETApp::settings().value("diagramview/gestures", false).toBool());
+bool DiagramView::gestures() const
+{
+	QSettings settings;
+	return(settings.value("diagramview/gestures", false).toBool());
 }
 
 /**
 	Manage wheel event of mouse
 	@param e QWheelEvent
 */
-void DiagramView::wheelEvent(QWheelEvent *e) {
-	if (m_event_interface) {
-		if (m_event_interface -> wheelEvent(e)) {
-			if (m_event_interface->isFinish()) {
-				emit (itemAdded());
-				delete m_event_interface; m_event_interface = nullptr;
-			}
-			return;
+void DiagramView::wheelEvent(QWheelEvent *event)
+{
+	if (m_event_interface && m_event_interface->wheelEvent(event)) return;
+
+		//Zoom and scrolling
+	QPoint angle = event->angleDelta();
+
+	if (gestures()) //When gesture mode is enable, we suppose the wheel event are made from a trackpad.
+	{
+		if (event->modifiers() == Qt::ControlModifier) //zoom
+		{
+			qreal value = angle.y();
+			zoom(1 + value/1000);
+		}
+		else //scroll
+		{
+			horizontalScrollBar()->setValue(horizontalScrollBar()->value() - angle.x());
+			verticalScrollBar()->setValue(verticalScrollBar()->value() - angle.y());
 		}
 	}
-
-	//Zoom and scrolling
-	if ( gestures() ) {
-		if (e -> modifiers() & Qt::ControlModifier)
-			e -> delta() > 0 ? zoomInSlowly() : zoomOutSlowly();
-		else
-			QGraphicsView::wheelEvent(e);
-	} else {
-		e -> delta() > 0 ? zoomIn(): zoomOut();
+	else if (event->modifiers() == Qt::NoModifier) //Else we suppose the wheel event are made from a mouse.
+	{
+		qreal value = angle.y();
+		zoom(1 + value/1000);
 	}
+	else
+		QGraphicsView::wheelEvent(event);
 }
 
-
 /**
- * Utilise le pincement du trackpad pour zoomer
  * @brief DiagramView::gestureEvent
+ * Use the pinch of the trackpad for zoom
  * @param event
  * @return
  */
-
-
-bool DiagramView::gestureEvent(QGestureEvent *event){
-	if (QGesture *gesture = event->gesture(Qt::PinchGesture)) {
+bool DiagramView::gestureEvent(QGestureEvent *event)
+{
+	if (QGesture *gesture = event->gesture(Qt::PinchGesture))
+	{
 		QPinchGesture *pinch = static_cast<QPinchGesture *>(gesture);
-		if (pinch->changeFlags() & QPinchGesture::ScaleFactorChanged){
+		if (pinch->changeFlags() & QPinchGesture::ScaleFactorChanged)
+		{
 			qreal value = gesture->property("scaleFactor").toReal();
-			if (value > 1){
-				zoomInSlowly();
-			}else{
-				zoomOutSlowly();
-			}
+			value > 1 ? zoom(1.02) : zoom(0.98);
 		}
 	}
 	return true;
@@ -617,15 +587,8 @@ void DiagramView::focusInEvent(QFocusEvent *e) {
 	mode if needed.
 */
 void DiagramView::keyPressEvent(QKeyEvent *e) {
-	if (m_event_interface) {
-		if (m_event_interface -> keyPressEvent(e)) {
-			if (m_event_interface->isFinish()) {
-				emit (itemAdded());
-				delete m_event_interface; m_event_interface = nullptr;
-			}
-			return;
-		}
-	}
+	if (m_event_interface && m_event_interface->keyPressEvent(e)) return;
+
 	switchToVisualisationModeIfNeeded(e);
 	QGraphicsView::keyPressEvent(e);
 }
@@ -635,15 +598,8 @@ void DiagramView::keyPressEvent(QKeyEvent *e) {
 	mode if needed.
 */
 void DiagramView::keyReleaseEvent(QKeyEvent *e) {
-	if (m_event_interface) {
-		if (m_event_interface -> KeyReleaseEvent(e)) {
-			if (m_event_interface->isFinish()) {
-				emit (itemAdded());
-				delete m_event_interface; m_event_interface = nullptr;
-			}
-			return;
-		}
-	}
+	if (m_event_interface && m_event_interface->KeyReleaseEvent(e)) return;
+
 	switchToSelectionModeIfNeeded(e);
 	QGraphicsView::keyReleaseEvent(e);
 }
@@ -762,25 +718,15 @@ void DiagramView::removeRow() {
 }
 
 /**
-	Ajuste le sceneRect (zone du schema visualisee par le DiagramView) afin que
-	celui inclut a la fois les elements dans et en dehors du cadre et le cadre
-	lui-meme.
-*/
-void DiagramView::adjustSceneRect() {
-	QRectF old_scene_rect = sceneRect();
-	
-	// rectangle delimitant l'ensemble des elements
-	QRectF elements_bounding_rect = scene -> itemsBoundingRect();
-	
-	// rectangle contenant le cadre = colonnes + cartouche
-	QRectF border_bounding_rect = scene -> border().adjusted(-Diagram::margin, -Diagram::margin, Diagram::margin, Diagram::margin);
-	
-	// ajuste la sceneRect
-	QRectF new_scene_rect = elements_bounding_rect.united(border_bounding_rect);
-	setSceneRect(new_scene_rect);
-	
-	// met a jour la scene
-	scene -> update(old_scene_rect.united(new_scene_rect));
+ * @brief DiagramView::adjustSceneRect
+ * Calcul and set the area of the scene visualized by this view
+ * The area are diagram sceneRect * 2.
+ */
+void DiagramView::adjustSceneRect()
+{
+	QRectF scene_rect = scene->sceneRect();
+	scene_rect.adjust(-Diagram::margin, -Diagram::margin, Diagram::margin, Diagram::margin);
+	setSceneRect(scene_rect);
 }
 
 /**
@@ -816,33 +762,6 @@ QRectF DiagramView::viewedSceneRect() const {
 	return(QRectF(scene_left_top, scene_right_bottom));
 }
 
-/**
-	Cette methode permet de determiner s'il faut ou non integrer au projet un
-	element dont on connait l'emplacement.
-	L'element droppe est integre a la collection du projet :
-	  * s'il appartient a un autre projet, quelque soit la specification de
-	  l'utilisateur a ce propos ;
-	  * s'il appartient a la collection commune ou a la collection
-	  personnelle ET que l'utilisateur a autorise l'integration automatique
-	  des elements dans les projets.
-	@param location Emplacement de l'element
-	@return true si l'element doit etre integre, false sinon
-	
-*/
-bool DiagramView::mustIntegrateElement(const ElementsLocation &location) const {
-	// l'utilisateur a-t-il autorise l'integration automatique des elements dans les projets ?
-	bool auto_integration_enabled = QETApp::settings().value("diagrameditor/integrate-elements", true).toBool();
-	
-	// l'element appartient-il a un projet et si oui, est-ce un autre projet ?
-	bool elmt_from_project = location.project();
-	bool elmt_from_another_project = elmt_from_project && location.project() != scene -> project();
-	
-	// faut-il integrer l'element ?
-	bool must_integrate_element = (elmt_from_another_project || (auto_integration_enabled && !elmt_from_project));
-	
-	return(must_integrate_element);
-}
-
 /**
 	@param tbt_loc A title block template location
 	@return true if the title block template needs to be integrated in the
@@ -857,24 +776,6 @@ bool DiagramView::mustIntegrateTitleBlockTemplate(const TitleBlockTemplateLocati
 	return(tbt_parent_project != scene -> project());
 }
 
-/**
-	@param location Emplacement de l'element a ajouter sur le schema
-	@param pos Position (dans les coordonnees de la vue) a laquelle l'element sera ajoute
-*/
-bool DiagramView::addElementAtPos(const ElementsLocation &location, const QPoint &pos) {
-	// construit une instance de l'element correspondant a l'emplacement
-	int state;
-	Element *el = ElementFactory::Instance()->createElement(location, 0, &state);
-	if (state) {
-		delete el;
-		return(false);
-	}
-	
-	//Add element to diagram
-	diagram() -> undoStack().push (new AddItemCommand<Element *>(el, diagram(), mapToScene(pos)));
-	return(true);
-}
-
 /**
 	Fait en sorte que le schema ne soit editable que s'il n'est pas en lecture
 	seule
@@ -911,12 +812,12 @@ void DiagramView::editSelectionProperties() {
 	}
 	
 	else {
-		QET::MessageBox::information(
+		QET::QetMessageBox::information(
 			this,
-			tr("Propri\351t\351s de la s\351lection"),
+			tr("Propriétés de la sélection"),
 			QString(
 				tr(
-					"La s\351lection contient %1.",
+					"La sélection contient %1.",
 					"%1 is a sentence listing the selected objects"
 				)
 			).arg(selection.sentence(DiagramContent::All | DiagramContent::SelectedOnly))
@@ -942,33 +843,36 @@ void DiagramView::editSelectedConductorColor() {
 	Edit the color of the given conductor
 	@param edited_conductor Conductor we want to change the color
 */
-void DiagramView::editConductorColor(Conductor *edited_conductor) {
-	if (scene -> isReadOnly()) return;
-	if (!edited_conductor) return;
+void DiagramView::editConductorColor(Conductor *edited_conductor)
+{
+	if (scene -> isReadOnly() || !edited_conductor) return;
 	
-	// store the initial properties of the provided conductor
+		// store the initial properties of the provided conductor
 	ConductorProperties initial_properties = edited_conductor -> properties();
 	
-	// prepare a color dialog showing the initial conductor color
+		// prepare a color dialog showing the initial conductor color
 	QColorDialog *color_dialog = new QColorDialog(this);
 	color_dialog -> setWindowTitle(tr("Choisir la nouvelle couleur de ce conducteur"));
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 	color_dialog -> setWindowFlags(Qt::Sheet);
 #endif
 	color_dialog -> setCurrentColor(initial_properties.color);
 	
-	// asks the user what color he wishes to apply
-	if (color_dialog -> exec() == QDialog::Accepted) {
+		// asks the user what color he wishes to apply
+	if (color_dialog -> exec() == QDialog::Accepted)
+	{
 		QColor new_color = color_dialog -> selectedColor();
-		if (new_color != initial_properties.color) {
-			// the user chose a different color
-			ConductorProperties new_properties = initial_properties;
-			new_properties.color = new_color;
-			
-			ChangeConductorPropertiesCommand *ccpc = new ChangeConductorPropertiesCommand(edited_conductor);
-			ccpc -> setOldSettings(initial_properties);
-			ccpc -> setNewSettings(new_properties);
-			diagram() -> undoStack().push(ccpc);
+		if (new_color != initial_properties.color)
+		{
+				// the user chose a different color
+			QVariant old_value, new_value;
+			old_value.setValue(initial_properties);
+			initial_properties.color = new_color;
+			new_value.setValue(initial_properties);
+
+			QPropertyUndoCommand *undo = new QPropertyUndoCommand(edited_conductor, "properties", old_value, new_value);
+			undo->setText(tr("Modifier les propriétés d'un conducteur", "undo caption"));
+			diagram() -> undoStack().push(undo);
 		}
 	}
 }
@@ -1003,7 +907,22 @@ void DiagramView::resetConductors() {
 	Gere les evenements de la DiagramView
 	@param e Evenement
 */
+/**
+ * @brief DiagramView::event
+ * Manage the event on this diagram view.
+ * -At first activation (QEvent::WindowActivate or QEvent::Show) we zoomFit.
+ * -Convert event interpreted to mouse event to gesture event if needed.
+ * -send Shortcut to view (by default send to QMenu /QAction)
+ * @param e the event.
+ * @return
+ */
 bool DiagramView::event(QEvent *e) {
+	if (Q_UNLIKELY(m_first_activation)) {
+		if (e -> type() == QEvent::Show) {
+			zoomFit();
+			m_first_activation = false;
+		}
+	}
 	// By default touch events are converted to mouse events. So
 	// after this event we will get a mouse event also but we want
 	// to handle touch events as gestures only. So we need this safeguard
@@ -1088,20 +1007,30 @@ bool DiagramView::selectedItemHasFocus() {
 void DiagramView::editSelection() {
 	if (scene -> isReadOnly() || scene -> selectedItems().size() != 1 ) return;
 
-	if (IndependentTextItem *iti = qgraphicsitem_cast<IndependentTextItem *>(scene->selectedItems().first())) {
+	QGraphicsItem *item = scene->selectedItems().first();
+
+		//We use dynamic_cast instead of qgraphicsitem_cast for QetGraphicsItem
+		//because they haven't got they own type().
+		//Use qgraphicsitem_cast will have weird behavior for this class.
+	if (IndependentTextItem *iti = qgraphicsitem_cast<IndependentTextItem *>(item))
 		iti -> edit();
-	} else if (QetGraphicsItem *qgi = qgraphicsitem_cast<QetGraphicsItem *> (scene->selectedItems().first())) {
+	else if (QetGraphicsItem *qgi = dynamic_cast<QetGraphicsItem *> (item))
 		qgi -> editProperty();
-	}
+	else if (Conductor *c = qgraphicsitem_cast<Conductor *>(item))
+		c -> editProperty();
 }
 
 /**
  * @brief DiagramView::setEventInterface
  * Set an event interface to diagram view.
+ * If diagram view already have an event interface, he delete it before.
+ * Diagram view take ownership of event interface and delete it when event interface is finish
  */
-void DiagramView::setEventInterface(DVEventInterface *interface) {
+void DiagramView::setEventInterface(DVEventInterface *event_interface)
+{
 	if (m_event_interface) delete m_event_interface;
-	m_event_interface = interface;
+	m_event_interface = event_interface;
+	connect(m_event_interface, &DVEventInterface::finish, this, [=](){delete this->m_event_interface; this->m_event_interface = nullptr;}, Qt::QueuedConnection);
 }
 
 /**
@@ -1109,7 +1038,7 @@ void DiagramView::setEventInterface(DVEventInterface *interface) {
 	@param e Evenement decrivant la demande de menu contextuel
 */
 void DiagramView::contextMenuEvent(QContextMenuEvent *e) {
-	if (QGraphicsItem *qgi = scene -> itemAt(mapToScene(e -> pos()))) {
+	if (QGraphicsItem *qgi = scene -> itemAt(mapToScene(e -> pos()), transform())) {
 		if (!qgi -> isSelected()) scene -> clearSelection();
 		qgi -> setSelected(true);
 	}
@@ -1155,48 +1084,16 @@ QETDiagramEditor *DiagramView::diagramEditor() const {
  * @brief DiagramView::mouseDoubleClickEvent
  * @param e
  */
-void DiagramView::mouseDoubleClickEvent(QMouseEvent *e) {
-
-	if (m_event_interface) {
-		if (m_event_interface -> mouseDoubleClickEvent(e)) {
-			if (m_event_interface->isFinish()) {
-				emit (itemAdded());
-				delete m_event_interface; m_event_interface = nullptr;
-			}
-			return;
-		}
-	}
+void DiagramView::mouseDoubleClickEvent(QMouseEvent *e)
+{
+	if (m_event_interface && m_event_interface -> mouseDoubleClickEvent(e)) return;
 
 	BorderTitleBlock &bi = scene -> border_and_titleblock;
 	
-	//Get the rectangle of the titleblock
-	QRectF titleblock_rect(
-		Diagram::margin,
-		Diagram::margin + bi.diagramHeight(),
-		bi.titleBlockWidth(),
-		bi.titleBlockHeight()
-	);
-	
-	// Get the rectangle of the header column
-	QRectF columns_rect(
-		Diagram::margin,
-		Diagram::margin,
-		bi.borderWidth(),
-		bi.columnsHeaderHeight()
-	);
-	
-	// Get the rectangle of the header row
-	QRectF rows_rect(
-		Diagram::margin,
-		Diagram::margin,
-		bi.rowsHeaderWidth(),
-		bi.diagramHeight()
-	);
-	
 	//Get the click pos on the diagram
 	QPointF click_pos = viewportTransform().inverted().map(e -> pos());
 	
-	if (titleblock_rect.contains(click_pos) || columns_rect.contains(click_pos) || rows_rect.contains(click_pos)) {
+	if (bi.titleBlockRect().contains(click_pos) || bi.columnsRect().contains(click_pos) || bi.rowsRect().contains(click_pos)) {
 		e->accept();
 		editDiagramProperties();
 		return;
@@ -1204,32 +1101,6 @@ void DiagramView::mouseDoubleClickEvent(QMouseEvent *e) {
 	QGraphicsView::mouseDoubleClickEvent(e);
 }
 
-/**
-	Cette methode ajoute l'element designe par l'emplacement location a la
-	position pos. Si necessaire, elle demande l'integration de l'element au
-	projet.
-	@see mustIntegrateElement
-*/
-void DiagramView::addDroppedElement() {
-	ElementsLocation location = next_location_;
-	QPoint pos = next_position_;
-	
-	if (!mustIntegrateElement(location)) {
-		addElementAtPos(location, pos);
-	} else {
-		QString error_msg;
-		IntegrationMoveElementsHandler *integ_handler = new IntegrationMoveElementsHandler(this);
-		QString integ_path = scene -> project() -> integrateElement(location.toString(), integ_handler, error_msg);
-		delete integ_handler;
-		if (integ_path.isEmpty()) {
-			qDebug() << "DiagramView::addDroppedElement : Impossible d'ajouter l'element. Motif : " << qPrintable(error_msg);
-			return;
-		}
-		addElementAtPos(ElementsLocation::locationFromString(integ_path), pos);
-	}
-	adjustSceneRect();
-}
-
 /**
 	@param tbt TitleBlockTemplateLocation
 */
