@@ -227,7 +227,7 @@ MovePartsCommand::MovePartsCommand(
 	const QList<QGraphicsItem *> parts,
 	QUndoCommand *parent
 ) :
-	ElementEditionCommand(QObject::tr("d\351placement", "undo caption"), scene, 0, parent),
+	ElementEditionCommand(QObject::tr("déplacement", "undo caption"), scene, 0, parent),
 	movement(m),
 	first_redo(true)
 {
@@ -302,87 +302,6 @@ void AddPartCommand::redo() {
 	editor_scene_ -> addItem(part);
 }
 
-/**
-	Constructeur
-	@param name   nom de la propriete modifiee
-	@param part   partie modifiee
-	@param prop   propriete modifiee
-	@param old_v  ancienne valeur
-	@param new_v  nouvelle valeur
-	@param parent qUndoCommand parent
-*/
-ChangePartCommand::ChangePartCommand(
-	const QString &name,
-	CustomElementPart *part,
-	const char *prop,
-	const QVariant &old_v,
-	const QVariant &new_v,
-	QUndoCommand *parent
-) :
-	ElementEditionCommand(QString(QObject::tr("modification %1", "undo caption")).arg(name), 0, 0, parent),
-	cep(part),
-	property(prop),
-	old_value(old_v),
-	new_value(new_v)
-{
-}
-
-/// Destructeur
-ChangePartCommand::~ChangePartCommand() {
-}
-
-/**
- * @brief ChangePartCommand::undo
- */
-void ChangePartCommand::undo()
-{
-	cep -> setProperty(property, old_value);
-	ElementEditionCommand::undo();
-}
-
-/**
- * @brief ChangePartCommand::redo
- */
-void ChangePartCommand::redo()
-{
-	cep -> setProperty(property, new_value);
-	ElementEditionCommand::redo();
-}
-
-/**
-	Constructeur
-	@param p Polygone edite
-	@param o_points points avant le changement
-	@param n_points points apres le changement
-	@param parent QUndoCommand parent
-*/
-ChangePolygonPointsCommand::ChangePolygonPointsCommand(
-	PartPolygon *p,
-	const QVector<QPointF> &o_points,
-	const QVector<QPointF> &n_points,
-	QUndoCommand *parent
-) :
-	ElementEditionCommand(QObject::tr("modification points polygone", "undo caption"), 0, 0, parent),
-	polygon(p),
-	old_points(o_points),
-	new_points(n_points)
-{
-}
-
-/// Destructeur
-ChangePolygonPointsCommand::~ChangePolygonPointsCommand() {
-}
-
-/// Annule le changement
-void ChangePolygonPointsCommand::undo() {
-	polygon -> setPolygon(old_points);
-}
-
-/// Refait le changement
-void ChangePolygonPointsCommand::redo() {
-	polygon -> setPolygon(new_points);
-}
-
 /**
 	Constructeur
 	@param element_scene Element edite
@@ -444,7 +363,7 @@ ChangeZValueCommand::ChangeZValueCommand(
 		setText(QObject::tr("rapprocher", "undo caption"));
 		applyRaise(items_list);
 	} else if (option == Lower) {
-		setText(QObject::tr("\351loigner", "undo caption"));
+		setText(QObject::tr("éloigner", "undo caption"));
 		applyLower(items_list);
 	} else if (option == SendBackward) {
 		setText(QObject::tr("envoyer au fond", "undo caption"));
@@ -679,7 +598,7 @@ ChangePropertiesCommand::ChangePropertiesCommand(ElementScene *scene, QString ty
 {
 	m_type << scene->m_elmt_type << type;
 	m_info << scene->m_elmt_kindInfo << info;
-	setText(QObject::tr("Modifier les propri\351t\351s"));
+	setText(QObject::tr("Modifier les propriétés"));
 }
 
 ChangePropertiesCommand::~ChangePropertiesCommand() {}
