@@ -72,15 +72,15 @@ void ElementScene::mouseMoveEvent(QGraphicsSceneMouseEvent *e) {
 	if (m_event_interface) {
 		if (m_event_interface -> mouseMoveEvent(e)) {
 			if (m_event_interface->isFinish()) {
-				emit(partsAdded());
 				delete m_event_interface; m_event_interface = nullptr;
+				emit(partsAdded());
 			}
 			return;
 		}
 	}
 
 	QPointF event_pos = e -> scenePos();
-	if (!e -> modifiers() & Qt::ControlModifier)
+	if (!(e -> modifiers() & Qt::ControlModifier))
 		event_pos = snapToGrid(event_pos);
 	
 	if (behavior == PasteArea) {
@@ -101,8 +101,8 @@ void ElementScene::mousePressEvent(QGraphicsSceneMouseEvent *e) {
 	if (m_event_interface) {
 		if (m_event_interface -> mousePressEvent(e)) {
 			if (m_event_interface->isFinish()) {
-				emit(partsAdded());
 				delete m_event_interface; m_event_interface = nullptr;
+				emit(partsAdded());
 			}
 			return;
 		}
@@ -119,8 +119,8 @@ void ElementScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *e) {
 	if (m_event_interface) {
 		if (m_event_interface -> mouseReleaseEvent(e)) {
 			if (m_event_interface->isFinish()) {
-				emit(partsAdded());
 				delete m_event_interface; m_event_interface = nullptr;
+				emit(partsAdded());
 			}
 			return;
 		}
@@ -145,8 +145,8 @@ void ElementScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event) {
 	if (m_event_interface) {
 		if (m_event_interface -> mouseDoubleClickEvent(event)) {
 			if (m_event_interface->isFinish()) {
-				emit(partsAdded());
 				delete m_event_interface; m_event_interface = nullptr;
+				emit(partsAdded());
 			}
 			return;
 		}
@@ -164,8 +164,8 @@ void ElementScene::keyPressEvent(QKeyEvent *event) {
 	if (m_event_interface) {
 		if (m_event_interface -> keyPressEvent(event)) {
 			if (m_event_interface->isFinish()) {
-				emit(partsAdded());
 				delete m_event_interface; m_event_interface = nullptr;
+				emit(partsAdded());
 			}
 			return;
 		}
@@ -173,6 +173,17 @@ void ElementScene::keyPressEvent(QKeyEvent *event) {
 	QGraphicsScene::keyPressEvent(event);
 }
 
+/**
+ * @brief ElementScene::contextMenuEvent
+ * Display the context menu event, only if behavior are Normal
+ * @param event
+ */
+void ElementScene::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
+{
+	if (behavior == ElementScene::Normal)
+		element_editor -> contextMenu(event->screenPos());
+}
+
 /**
 	Dessine l'arriere-plan de l'editeur, cad l'indicateur de hotspot.
 	@param p Le QPainter a utiliser pour dessiner
@@ -187,7 +198,9 @@ void ElementScene::drawForeground(QPainter *p, const QRectF &rect) {
 	p -> setRenderHint(QPainter::TextAntialiasing, true);
 	p -> setRenderHint(QPainter::SmoothPixmapTransform, false);
 	
-	p -> setPen(Qt::red);
+	QPen pen(Qt::red);
+	pen.setCosmetic(true);
+	p -> setPen(pen);
 	p -> setBrush(Qt::NoBrush);
 	p -> drawLine(-20, 0, 20, 0);
 	p -> drawLine(0, -20, 0, 20);
@@ -199,14 +212,24 @@ void ElementScene::drawForeground(QPainter *p, const QRectF &rect) {
  * Set a new event interface
  * @param interface
  */
-void ElementScene::setEventInterface(ESEventInterface *interface) {
+void ElementScene::setEventInterface(ESEventInterface *event_interface) {
 	if (m_event_interface) {
 		delete m_event_interface;
 		//We must to re-init because previous interface
 		//Reset his own init when deleted
-		interface->init();
+		event_interface->init();
 	}
-	m_event_interface = interface;
+	m_event_interface = event_interface;
+}
+
+/**
+ * @brief ElementScene::setBehavior
+ * Modifie the current behavior of this scene
+ * @param b
+ */
+void ElementScene::setBehavior(ElementScene::Behavior b)
+{
+	behavior = b;
 }
 
 /**
@@ -233,35 +256,40 @@ void ElementScene::setGrid(int x_g, int y_g) {
 }
 
 /**
-	Exporte l'element en XML
-	@param all_parts Booleen (a vrai par defaut) indiquant si le XML genere doit
-	representer tout l'element ou seulement les elements selectionnes
-	@return un document XML decrivant l'element
-*/
-const QDomDocument ElementScene::toXml(bool all_parts) {
+ * @brief ElementScene::toXml
+ * Export this element as a xml file
+ * @param all_parts (true by default) if true, export the entire element in xml,
+ * if false, only export the selected parts.
+ * @return an xml document that describe the element.
+ */
+const QDomDocument ElementScene::toXml(bool all_parts)
+{
 	QRectF size= elementSceneGeometricRect();
-	//if the element doesn't contains the origin point of the scene
-	//we move the element to the origin for solve this default before saving
-	if (!size.contains(0,0) && all_parts) {
+
+		//if the element doesn't contains the origin point of the scene
+		//we move the element to the origin for solve this default before saving
+	if (!size.contains(0,0) && all_parts)
+	{
 		centerElementToOrigine();
-		//recalcul the size after movement
+			//recalcul the size after movement
 		size= elementSceneGeometricRect();
 	}
 
-	//define the size of the element by the upper multiple of 10
+		//define the size of the element by the upper multiple of 10
 	int upwidth = ((qRound(size.width())/10)*10)+10;
 	if ((qRound(size.width())%10) > 6) upwidth+=10;
 
 	int upheight = ((qRound(size.height())/10)*10)+10;
 	if ((qRound(size.height())%10) > 6) upheight+=10;
 
-	//the margin between the real size of the element and the rectangle that delimits
+		//the margin between the real size of the element and the rectangle that delimits
 	int xmargin = qRound(upwidth - size.width());
 	int ymargin = qRound(upheight - size.height());
 
-	// document XML
+		// document XML
 	QDomDocument xml_document;
-	// racine du document XML
+
+		//Root of xml document
 	QDomElement root = xml_document.createElement("definition");
 	root.setAttribute("type",        "element");
 	root.setAttribute("width",       QString("%1").arg(upwidth));
@@ -271,27 +299,36 @@ const QDomDocument ElementScene::toXml(bool all_parts) {
 	root.setAttribute("orientation", "dyyy"); //we keep the orientation for compatibility with previous version of qet
 	root.setAttribute("version", QET::version);
 	root.setAttribute("link_type", m_elmt_type);
+
+		//Uuid used to compare two elements
+	QDomElement uuid = xml_document.createElement("uuid");
+	uuid.setAttribute("uuid", QUuid::createUuid().toString());
+	root.appendChild(uuid);
 	
-	// noms de l'element
+		//names of element
 	root.appendChild(_names.toXml(xml_document));
 
-	if (m_elmt_type == "slave" || m_elmt_type == "master") {
+	if (m_elmt_type == "slave" || m_elmt_type == "master")
+	{
 		QDomElement kindInfo = xml_document.createElement("kindInformations");
 		m_elmt_kindInfo.toXml(kindInfo, "kindInformation");
 		root.appendChild(kindInfo);
 	}
 	
-	// informations complementaires de l'element
+		//complementary information about the element
 	QDomElement informations_element = xml_document.createElement("informations");
 	root.appendChild(informations_element);
 	informations_element.appendChild(xml_document.createTextNode(informations()));
 	
 	QDomElement description = xml_document.createElement("description");
-	// description de l'element
-	foreach(QGraphicsItem *qgi, zItems()) {
-		// si l'export ne concerne que la selection, on ignore les parties non selectionnees
+
+		//the graphic description of the element
+	foreach(QGraphicsItem *qgi, zItems())
+	{
+			//If the export concerns only the selection, the not selected part is ignored
 		if (!all_parts && !qgi -> isSelected()) continue;
-		if (CustomElementPart *ce = dynamic_cast<CustomElementPart *>(qgi)) {
+		if (CustomElementPart *ce = dynamic_cast<CustomElementPart *>(qgi))
+		{
 			if (ce -> isUseless()) continue;
 			description.appendChild(ce -> toXml(xml_document));
 		}
@@ -458,11 +495,6 @@ void ElementScene::copy() {
 	last_copied_ = clipboard_content;
 }
 
-void ElementScene::contextMenu(QContextMenuEvent *event) {
-	if (behavior == ElementScene::Normal)
-		element_editor -> contextMenu(event);
-}
-
 QETElementEditor* ElementScene::editor() const {
 	return element_editor;
 }
@@ -530,15 +562,15 @@ void ElementScene::slot_editAuthorInformations() {
 	// cree un dialogue
 	QDialog dialog_author(element_editor);
 	dialog_author.setModal(true);
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 	dialog_author.setWindowFlags(Qt::Sheet);
 #endif
 	dialog_author.setMinimumSize(400, 260);
-	dialog_author.setWindowTitle(tr("\311diter les informations sur l'auteur", "window title"));
+	dialog_author.setWindowTitle(tr("Éditer les informations sur l'auteur", "window title"));
 	QVBoxLayout *dialog_layout = new QVBoxLayout(&dialog_author);
 	
 	// ajoute un champ explicatif au dialogue
-	QLabel *information_label = new QLabel(tr("Vous pouvez utiliser ce champ libre pour mentionner les auteurs de l'\351l\351ment, sa licence, ou tout autre renseignement que vous jugerez utile."));
+	QLabel *information_label = new QLabel(tr("Vous pouvez utiliser ce champ libre pour mentionner les auteurs de l'élément, sa licence, ou tout autre renseignement que vous jugerez utile."));
 	information_label -> setAlignment(Qt::AlignJustify | Qt::AlignVCenter);
 	information_label -> setWordWrap(true);
 	dialog_layout -> addWidget(information_label);
@@ -586,16 +618,16 @@ void ElementScene::slot_editNames() {
 	
 	// cree un dialogue
 	QDialog dialog(element_editor);
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 	dialog.setWindowFlags(Qt::Sheet);
 #endif
 	dialog.setModal(true);
 	dialog.setMinimumSize(400, 330);
-	dialog.setWindowTitle(tr("\311diter les noms", "window title"));
+	dialog.setWindowTitle(tr("Éditer les noms", "window title"));
 	QVBoxLayout *dialog_layout = new QVBoxLayout(&dialog);
 	
 	// ajoute un champ explicatif au dialogue
-	QLabel *information_label = new QLabel(tr("Vous pouvez sp\351cifier le nom de l'\351l\351ment dans plusieurs langues."));
+	QLabel *information_label = new QLabel(tr("Vous pouvez spécifier le nom de l'élément dans plusieurs langues."));
 	information_label -> setAlignment(Qt::AlignJustify | Qt::AlignVCenter);
 	information_label -> setWordWrap(true);
 	dialog_layout -> addWidget(information_label);
@@ -792,7 +824,7 @@ bool ElementScene::applyInformations(const QDomDocument &xml_document, QString *
 	QDomElement root = xml_document.documentElement();
 	if (root.tagName() != "definition" || root.attribute("type") != "element") {
 		if (error_message) {
-			*error_message = tr("Ce document XML n'est pas une d\351finition d'\351l\351ment.", "error message");
+			*error_message = tr("Ce document XML n'est pas une définition d'élément.", "error message");
 		}
 		return(false);
 	}
@@ -832,7 +864,7 @@ ElementContent ElementScene::loadContent(const QDomDocument &xml_document, QStri
 	QDomElement root = xml_document.documentElement();
 	if (root.tagName() != "definition" || root.attribute("type") != "element") {
 		if (error_message) {
-			*error_message = tr("Ce document XML n'est pas une d\351finition d'\351l\351ment.", "error message");
+			*error_message = tr("Ce document XML n'est pas une définition d'élément.", "error message");
 		}
 		return(loaded_parts);
 	}
@@ -968,9 +1000,9 @@ void ElementScene::centerElementToOrigine() {
 	int center_y = qRound(size.center().y());
 
 	//define the movement of translation
-	int move_x = center_x - (qRound(center_x) %10);
+	int move_x = center_x - (center_x %10);
 	if (center_x < 0) move_x -= 10;
-	int move_y = center_y - (qRound(center_y) %10);
+	int move_y = center_y - (center_y %10);
 	if (center_y < 0) move_y -= 10;
 
 		//move each primitive by @move
@@ -999,11 +1031,16 @@ void ElementScene::managePrimitivesGroups() {
 		decorator_ -> hide();
 	}
 	
-	// should we hide the decorator?
+		// should we hide the decorator?
 	QList<QGraphicsItem *> selected_items = zItems(ElementScene::Selected | ElementScene::IncludeTerminals);
-	if (!selected_items.count()) {
+	if (selected_items.size() == 0)
 		decorator_ -> hide();
-	} else {
+	else if (selected_items.size() == 1 &&
+			 selected_items.first()->type() != PartText::Type &&
+			 selected_items.first()->type() != PartTextField::Type)
+		decorator_->hide();
+	else
+	{
 		decorator_ -> setZValue(1000000);
 		decorator_ -> setPos(0, 0);
 		decorator_ -> setItems(selected_items);
