@@ -22,7 +22,6 @@
 #include "diagramprintdialog.h"
 #include "exportdialog.h"
 #include "qetapp.h"
-#include "qettabwidget.h"
 #include "qetelementeditor.h"
 #include "interactivemoveelementshandler.h"
 #include "borderpropertieswidget.h"
@@ -30,11 +29,12 @@
 #include "conductorpropertieswidget.h"
 #include "qeticons.h"
 #include "qetmessagebox.h"
-#include "qettabbar.h"
 #include "qettemplateeditor.h"
 #include "diagramfoliolist.h"
 #include "projectpropertiesdialog.h"
 
+#include <QTabWidget>
+
 /**
 	Constructeur
 	@param project projet a visualiser
@@ -120,7 +120,7 @@ QList<Diagram *> ProjectView::getDiagrams(ProjectSaveOptions options) {
 	@return le schema actuellement active
 */
 DiagramView *ProjectView::currentDiagram() const {
-	int current_tab_index = tabs_ -> currentIndex();
+	int current_tab_index = m_tab -> currentIndex();
 	return(diagram_ids_[current_tab_index]);
 }
 
@@ -234,7 +234,7 @@ int ProjectView::tryClosingDiagrams() {
 	if (title.isEmpty()) title = "QElectroTech ";
 
 	int close_dialog = QMessageBox::question(this, title,
-								   tr("Le projet \340 \351t\351 modifi\351.\n"
+								   tr("Le projet à été modifié.\n"
 									  "Voulez-vous enregistrer les modifications ?"),
 								   QMessageBox::Save | QMessageBox::Discard
 								   | QMessageBox::Cancel,
@@ -260,7 +260,7 @@ QString ProjectView::askUserForFilePath(bool assign) {
 		this,
 		tr("Enregistrer sous", "dialog title"),
 		project_ -> currentDir(),
-		tr("Sch\351ma QElectroTech (*.qet)", "filetypes allowed when saving a diagram file")
+        tr("Projet QElectroTech (*.qet)", "filetypes allowed when saving a project file")
 	);
 	
 	// if no filepath is provided, return an empty string
@@ -282,7 +282,7 @@ QString ProjectView::askUserForFilePath(bool assign) {
 	view is not associated to any project.
 */
 QETResult ProjectView::noProjectResult() const {
-	QETResult no_project(tr("aucun projet affich\351", "error message"), false);
+	QETResult no_project(tr("aucun projet affiché", "error message"), false);
 	return(no_project);
 }
 
@@ -314,7 +314,7 @@ void ProjectView::addNewDiagramFolioList() {
 		DiagramView *new_diagram_view = new DiagramView(d);
 		addDiagram(new_diagram_view);
 		showDiagram(new_diagram_view);
-		tabs_->moveTab(diagrams().size()-1, i);
+		m_tab->tabBar()->moveTab(diagrams().size()-1, i);
 		i++;
 	}
 }
@@ -337,7 +337,7 @@ void ProjectView::addDiagram(DiagramView *diagram) {
 	if (diagram_ids_.values().contains(diagram)) return;
 	
 	// Add new tab for the diagram
-	tabs_ -> addTab(diagram, QET::Icons::Diagram, diagram -> title());
+	m_tab -> addTab(diagram, QET::Icons::Diagram, diagram -> title());
 	diagram -> setFrameStyle(QFrame::Plain | QFrame::NoFrame);
 
 	diagrams_ << diagram;
@@ -366,10 +366,10 @@ void ProjectView::removeDiagram(DiagramView *diagram_view) {
 	
 
 	//Ask confirmation to user.
-	int answer = QET::MessageBox::question(
+	int answer = QET::QetMessageBox::question(
 		this,
-		tr("Supprimer le sch\351ma ?", "message box title"),
-		tr("\312tes-vous s\373r de vouloir supprimer ce sch\351ma du projet ? Ce changement est irr\351versible.", "message box content"),
+        tr("Supprimer le folio ?", "message box title"),
+        tr("Êtes-vous sûr  de vouloir supprimer ce folio du projet ? Ce changement est irréversible.", "message box content"),
 		QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel,
 		QMessageBox::No
 	);
@@ -379,7 +379,7 @@ void ProjectView::removeDiagram(DiagramView *diagram_view) {
 	
 	// enleve le DiagramView des onglets
 	int diagram_tab_id = diagram_ids_.key(diagram_view);
-	tabs_ -> removeTab(diagram_tab_id);
+	m_tab -> removeTab(diagram_tab_id);
 	diagrams_.removeAll(diagram_view);
 	rebuildDiagramsMap();
 	
@@ -412,7 +412,7 @@ void ProjectView::removeDiagram(Diagram *diagram) {
 */
 void ProjectView::showDiagram(DiagramView *diagram) {
 	if (!diagram) return;
-	tabs_ -> setCurrentWidget(diagram);
+	m_tab -> setCurrentWidget(diagram);
 }
 
 /**
@@ -422,7 +422,7 @@ void ProjectView::showDiagram(DiagramView *diagram) {
 void ProjectView::showDiagram(Diagram *diagram) {
 	if (!diagram) return;
 	if (DiagramView *diagram_view = findDiagram(diagram)) {
-		tabs_ -> setCurrentWidget(diagram_view);
+		m_tab -> setCurrentWidget(diagram_view);
 	}
 }
 
@@ -470,7 +470,7 @@ void ProjectView::moveDiagramUp(DiagramView *diagram_view) {
 		// le schema est le premier du projet
 		return;
 	}
-	tabs_ -> moveTab(diagram_view_position, diagram_view_position - 1);
+	m_tab -> tabBar() -> moveTab(diagram_view_position, diagram_view_position - 1);
 }
 
 /**
@@ -491,7 +491,7 @@ void ProjectView::moveDiagramDown(DiagramView *diagram_view) {
 		// le schema est le dernier du projet
 		return;
 	}
-	tabs_ -> moveTab(diagram_view_position, diagram_view_position + 1);
+	m_tab -> tabBar() -> moveTab(diagram_view_position, diagram_view_position + 1);
 }
 
 /**
@@ -501,6 +501,29 @@ void ProjectView::moveDiagramDown(Diagram *diagram) {
 	moveDiagramDown(findDiagram(diagram));
 }
 
+/*
+ * Deplace le schema diagram_view vers le haut / la gauche en position 0
+ */
+void ProjectView::moveDiagramUpTop(DiagramView *diagram_view)
+{
+	if (!diagram_view) return;
+
+	int diagram_view_position = diagram_ids_.key(diagram_view);
+	if (!diagram_view_position) {
+		// le schema est le premier du projet
+		return;
+	}
+	m_tab -> tabBar() -> moveTab(diagram_view_position, (diagrams().size(), 0));
+}
+
+/*
+ * Deplace le schema diagram vers le haut / la gauche en position 0
+ */
+void ProjectView::moveDiagramUpTop(Diagram *diagram)
+{
+	moveDiagramUpTop(findDiagram(diagram));
+}
+
 /**
 	Deplace le schema diagram_view vers le haut / la gauche x10
 */
@@ -512,7 +535,7 @@ void ProjectView::moveDiagramUpx10(DiagramView *diagram_view) {
 		// le schema est le premier du projet
 		return;
 	}
-	tabs_ -> moveTab(diagram_view_position, diagram_view_position - 10);
+	m_tab -> tabBar() -> moveTab(diagram_view_position, diagram_view_position - 10);
 }
 
 /**
@@ -533,7 +556,7 @@ void ProjectView::moveDiagramDownx10(DiagramView *diagram_view) {
 		// le schema est le dernier du projet
 		return;
 	}
-	tabs_ -> moveTab(diagram_view_position, diagram_view_position + 10);
+	m_tab -> tabBar() -> moveTab(diagram_view_position, diagram_view_position + 10);
 }
 
 /**
@@ -581,7 +604,7 @@ void ProjectView::exportProject() {
 	if (!project_) return;
 	
 	ExportDialog ed(project_, parentWidget());
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 	ed.setWindowFlags(Qt::Sheet);
 #endif
 	ed.exec();
@@ -668,7 +691,7 @@ int ProjectView::cleanProject() {
 	
 	// s'assure que le schema n'est pas en lecture seule
 	if (project_ -> isReadOnly()) {
-		QET::MessageBox::critical(
+		QET::QetMessageBox::critical(
 			this,
 			tr("Projet en lecture seule", "message box title"),
 			tr("Ce projet est en lecture seule. Il n'est donc pas possible de le nettoyer.", "message box content")
@@ -677,9 +700,9 @@ int ProjectView::cleanProject() {
 	}
 	
 	// construit un petit dialogue pour parametrer le nettoyage
-	QCheckBox *clean_tbt        = new QCheckBox(tr("Supprimer les mod\350les de cartouche inutilis\351s dans le projet"));
-	QCheckBox *clean_elements   = new QCheckBox(tr("Supprimer les \351l\351ments inutilis\351s dans le projet"));
-	QCheckBox *clean_categories = new QCheckBox(tr("Supprimer les cat\351gories vides"));
+	QCheckBox *clean_tbt        = new QCheckBox(tr("Supprimer les modèles de cartouche inutilisés dans le projet"));
+	QCheckBox *clean_elements   = new QCheckBox(tr("Supprimer les éléments inutilisés dans le projet"));
+	QCheckBox *clean_categories = new QCheckBox(tr("Supprimer les catégories vides"));
 	QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
 	
 	clean_tbt        -> setChecked(true);
@@ -687,7 +710,7 @@ int ProjectView::cleanProject() {
 	clean_categories -> setChecked(true);
 	
 	QDialog clean_dialog(parentWidget());
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 	clean_dialog.setWindowFlags(Qt::Sheet);
 #endif
 	
@@ -703,9 +726,10 @@ int ProjectView::cleanProject() {
 	connect(buttons, SIGNAL(rejected()), &clean_dialog, SLOT(reject()));
 	
 	int clean_count = 0;
-	if (clean_dialog.exec() == QDialog::Accepted) {
+	if (clean_dialog.exec() == QDialog::Accepted)
+	{
 		if (clean_tbt -> isChecked()) {
-			project_ -> cleanUnusedTitleBlocKTemplates();
+			project_->embeddedTitleBlockTemplatesCollection()->deleteUnusedTitleBlocKTemplates();
 		}
 		if (clean_elements -> isChecked()) {
 			InteractiveMoveElementsHandler *handler = new InteractiveMoveElementsHandler(this);
@@ -727,7 +751,7 @@ int ProjectView::cleanProject() {
 	Initialize actions for this widget.
 */
 void ProjectView::initActions() {
-	add_new_diagram_ = new QAction(QET::Icons::Add, tr("Ajouter un sch\351ma"), this);
+    add_new_diagram_ = new QAction(QET::Icons::AddFolio, tr("Ajouter un folio"), this);
 	connect(add_new_diagram_, SIGNAL(triggered()), this, SLOT(addNewDiagram()));
 }
 
@@ -736,35 +760,33 @@ void ProjectView::initActions() {
 */
 void ProjectView::initWidgets() {
 	setObjectName("ProjectView");
-	setWindowIcon(QET::Icons::ProjectFile);
+	setWindowIcon(QET::Icons::ProjectFileGP);
 	
 	// initialize the "fallback" widget
 	fallback_widget_ = new QWidget();
 	fallback_label_ = new QLabel(
 		tr(
-			"Ce projet ne contient aucun sch\351ma",
+            "Ce projet ne contient aucun folio",
 			"label displayed when a project contains no diagram"
 		)
 	);
 	fallback_label_ -> setAlignment(Qt::AlignVCenter | Qt::AlignHCenter);
 	
 	// initialize tabs
-	tabs_ = new QETTabWidget();
-	tabs_ -> setMovable(true);
+	m_tab = new QTabWidget(this);
+	m_tab -> setMovable(true);
 	
-	QToolButton *add_new_diagram_button = new QToolButton();
+	QToolButton *add_new_diagram_button = new QToolButton;
 	add_new_diagram_button -> setDefaultAction(add_new_diagram_);
 	add_new_diagram_button -> setAutoRaise(true);
-	tabs_ -> setCornerWidget(add_new_diagram_button, Qt::TopRightCorner);
+	m_tab -> setCornerWidget(add_new_diagram_button, Qt::TopRightCorner);
 	
-	connect(tabs_, SIGNAL(currentChanged(int)),   this, SLOT(tabChanged(int)));
-	connect(tabs_, SIGNAL(tabDoubleClicked(int)), this, SLOT(tabDoubleClicked(int)));
-	connect(tabs_, SIGNAL(firstTabInserted()),    this, SLOT(firstTabInserted()));
-	connect(tabs_, SIGNAL(lastTabRemoved()),      this, SLOT(lastTabRemoved()));
-	connect(tabs_, SIGNAL(tabMoved(int, int)),    this, SLOT(tabMoved(int, int)));
+	connect(m_tab, SIGNAL(currentChanged(int)), this, SLOT(tabChanged(int)));
+	connect(m_tab, SIGNAL(tabBarDoubleClicked(int)), this, SLOT(tabDoubleClicked(int)));
+	connect(m_tab->tabBar(), SIGNAL(tabMoved(int, int)), this, SLOT(tabMoved(int, int)));
 	
 	fallback_widget_ -> setVisible(false);
-	tabs_ -> setVisible(false);
+	m_tab -> setVisible(false);
 }
 
 /**
@@ -775,14 +797,14 @@ void ProjectView::initLayout() {
 	fallback_widget_layout_ -> addWidget(fallback_label_);
 	
 	layout_ = new QVBoxLayout(this);
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 	layout_ -> setContentsMargins(0, 8, 0, 0);
 #else
 	layout_ -> setContentsMargins(0, 0, 0, 0);
 #endif
 	layout_ -> setSpacing(0);
 	layout_ -> addWidget(fallback_widget_);
-	layout_ -> addWidget(tabs_);
+	layout_ -> addWidget(m_tab);
 }
 
 
@@ -805,7 +827,7 @@ void ProjectView::loadDiagrams() {
 	// If project have the folios list, move it at the beginning of the project
 	if (project_ -> getFolioSheetsQuantity()) {
 		for (int i = 0; i < project_->getFolioSheetsQuantity(); i++)
-		tabs_ -> moveTab(diagrams().size()-1, + 1);
+		m_tab -> tabBar() -> moveTab(diagrams().size()-1, + 1);
 	}
 }
 
@@ -831,7 +853,7 @@ void ProjectView::adjustReadOnlyState() {
 	bool editable = !(project_ -> isReadOnly());
 	
 	// prevent users from moving existing diagrams
-	tabs_ -> setMovable(editable);
+	m_tab -> setMovable(editable);
 	// prevent users from adding new diagrams
 	add_new_diagram_ -> setEnabled(editable);
 	
@@ -847,7 +869,7 @@ void ProjectView::adjustReadOnlyState() {
 void ProjectView::updateTabTitle(DiagramView *diagram, const QString &diagram_title) {
 	int diagram_tab_id = diagram_ids_.key(diagram, -1);
 	if (diagram_tab_id != -1) {
-		tabs_ -> setTabText(diagram_tab_id, diagram_title);
+		m_tab -> setTabText(diagram_tab_id, diagram_title);
 	}
 }
 
@@ -906,17 +928,25 @@ void ProjectView::rebuildDiagramsMap() {
 	diagram_ids_.clear();
 	
 	foreach(DiagramView *diagram_view, diagrams_) {
-		int dv_idx = tabs_ -> indexOf(diagram_view);
+		int dv_idx = m_tab -> indexOf(diagram_view);
 		if (dv_idx == -1) continue;
 		diagram_ids_.insert(dv_idx, diagram_view);
 	}
 }
 
 /**
-	Gere les changements d'onglets
-	@param tab_id Index de l'onglet actif
-*/
+ * @brief ProjectView::tabChanged
+ * Manage the tab change.
+ * If tab_id == -1 (there is no diagram opened),
+ * we display the fallback widget.
+ * @param tab_id
+ */
 void ProjectView::tabChanged(int tab_id) {
+	if (tab_id == -1)
+		setDisplayFallbackWidget(true);
+	else if(m_tab->count() == 1)
+		setDisplayFallbackWidget(false);
+
 	emit(diagramActivated(diagram_ids_[tab_id]));
 }
 
@@ -932,20 +962,6 @@ void ProjectView::tabDoubleClicked(int tab_id) {
 	diagram_view -> editDiagramProperties();
 }
 
-/**
-	Gere le fait que le premier schema d'un projet soit insere
-*/
-void ProjectView::firstTabInserted() {
-	setDisplayFallbackWidget(false);
-}
-
-/**
-	Gere le fait que le dernier schema d'un projet soit enleve
-*/
-void ProjectView::lastTabRemoved() {
-	setDisplayFallbackWidget(true);
-}
-
 /**
 	@param fallback true pour afficher le widget de fallback, false pour
 	afficher les onglets.
@@ -954,5 +970,5 @@ void ProjectView::lastTabRemoved() {
 */
 void ProjectView::setDisplayFallbackWidget(bool fallback) {
 	fallback_widget_ -> setVisible(fallback);
-	tabs_ -> setVisible(!fallback);
+	m_tab -> setVisible(!fallback);
 }
