@@ -1,17 +1,17 @@
 /*
 	Copyright 2006-2015 The QElectroTech Team
 	This file is part of QElectroTech.
-	
+
 	QElectroTech is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
 	the Free Software Foundation, either version 2 of the License, or
 	(at your option) any later version.
-	
+
 	QElectroTech is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU General Public License for more details.
-	
+
 	You should have received a copy of the GNU General Public License
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
@@ -75,7 +75,7 @@ QETApp::QETApp(int &argc, char **argv) :
 	initLanguage();
 	QET::Icons::initIcons();
 	initStyle();
-	
+
 	if (!non_interactive_execution_ && isRunning()) {
 		// envoie les arguments a l'instance deja existante
 		non_interactive_execution_ = sendMessage(
@@ -83,42 +83,42 @@ QETApp::QETApp(int &argc, char **argv) :
 			QET::joinWithSpaces(QStringList(qet_arguments_.arguments()))
 		);
 	}
-	
+
 	if (non_interactive_execution_) {
 		std::exit(EXIT_SUCCESS);
 	}
-	
+
 	initSplashScreen();
 	initSystemTray();
-	
+
 	// prise en compte des messages des autres instances
 	connect(this, SIGNAL(messageAvailable(QString)), this, SLOT(messageReceived(const QString&)));
-	
+
 	// nettoyage avant de quitter l'application
 	connect(this, SIGNAL(aboutToQuit()), this, SLOT(cleanup()));
-	
+
 	// connexion pour le signalmapper
 	connect(&signal_map, SIGNAL(mapped(QWidget *)), this, SLOT(invertMainWindowVisibility(QWidget *)));
-	
+
 	setQuitOnLastWindowClosed(false);
 	connect(this, SIGNAL(lastWindowClosed()), this, SLOT(checkRemainingWindows()));
-	
-	setSplashScreenStep(tr("Chargement... Initialisation du cache des collections d'\351l\351ments", "splash screen caption"));
+
+	setSplashScreenStep(tr("Chargement... Initialisation du cache des collections d'éléments", "splash screen caption"));
 	if (!collections_cache_) {
 		QString cache_path = QETApp::configDir() + "/elements_cache.sqlite";
 		collections_cache_ = new ElementsCollectionCache(cache_path, this);
 		collections_cache_->setLocale(langFromSetting());
 	}
-	
+
 	// loads known collections into memory (this does not include items rendering made in elements panels)
-	setSplashScreenStep(tr("Chargement... Lecture des collections d'\351l\351ments", "splash screen caption"));
+	setSplashScreenStep(tr("Chargement... Lecture des collections d'éléments", "splash screen caption"));
 	foreach(ElementsCollection *collection, availableCollections()) {
 		collection -> reload();
 	}
-	
+
 	// on ouvre soit les fichiers passes en parametre soit un nouvel editeur de projet
 	if (qet_arguments_.files().isEmpty()) {
-		setSplashScreenStep(tr("Chargement... \311diteur de sch\351mas", "splash screen caption"));
+		setSplashScreenStep(tr("Chargement... Éditeur de schéma", "splash screen caption"));
 		new QETDiagramEditor();
 	} else {
 		setSplashScreenStep(tr("Chargement... Ouverture des fichiers", "splash screen caption"));
@@ -159,14 +159,14 @@ QETApp *QETApp::instance() {
 */
 void QETApp::setLanguage(const QString &desired_language) {
 	QString languages_path = languagesPath();
-	
+
 	// load Qt library translations
 	QString qt_l10n_path = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
 	if (!qtTranslator.load("qt_" + desired_language, qt_l10n_path)) {
 		qtTranslator.load("qt_" + desired_language, languages_path);
 	}
 	installTranslator(&qtTranslator);
-	
+
 	// charge les traductions pour l'application QET
 	if (!qetTranslator.load("qet_" + desired_language, languages_path)) {
 		// en cas d'echec, on retombe sur les chaines natives pour le francais
@@ -176,7 +176,7 @@ void QETApp::setLanguage(const QString &desired_language) {
 		}
 	}
 	installTranslator(&qetTranslator);
-	
+
 	QString ltr_special_string = tr(
 		"LTR",
 		"Translate this string to RTL if you are translating to a Right-to-Left language, else translate to LTR"
@@ -189,8 +189,10 @@ void QETApp::setLanguage(const QString &desired_language) {
  * @return the langage found in setting file
  * if nothing was found return the system local.
  */
-QString QETApp::langFromSetting() {
-	QString system_language = settings().value("lang", "system").toString();
+QString QETApp::langFromSetting()
+{
+	QSettings settings;
+	QString system_language = settings.value("lang", "system").toString();
 	if(system_language == "system") {system_language = QLocale::system().name().left(2);}
 	return system_language;
 }
@@ -316,18 +318,18 @@ ElementsCollection *QETApp::customElementsCollection() {
 */
 QList<ElementsCollection *> QETApp::availableCollections() {
 	QList<ElementsCollection *> coll_list;
-	
+
 	// collection commune
 	coll_list << commonElementsCollection();
-	
+
 	// collection perso
 	coll_list << customElementsCollection();
-	
+
 	// collections embarquees
 	foreach(QETProject *opened_project, registered_projects_.values()) {
 		coll_list << opened_project -> embeddedCollection();
 	}
-	
+
 	return(coll_list);
 }
 
@@ -349,7 +351,11 @@ QStringList QETApp::elementInfoKeys() {
 			  << "designation"
 			  << "manufacturer"
 			  << "manufacturer-reference"
-			  << "machine-manufacturer-reference";
+			  << "auxiliary1"
+			  << "auxiliary2"
+			  << "machine-manufacturer-reference"
+			  << "location"
+			  << "function";
 	return info_list;
 }
 
@@ -363,10 +369,14 @@ QStringList QETApp::elementInfoKeys() {
 QString QETApp::elementTranslatedInfoKey(QString &info) {
 	if (info == "label") return tr("Label");
 	else if (info == "comment") return tr("Commentaire");
-	else if (info == "designation") return tr("D\351signation");
+	else if (info == "designation") return tr("Désignation");
 	else if (info == "manufacturer") return tr("Fabricant");
-	else if (info == "manufacturer-reference") return tr("R\351f\351rence fabricant");
-	else if (info == "machine-manufacturer-reference") return tr("R\351f\351rence fabricant machine");
+	else if (info == "manufacturer-reference") return tr("Référence fabricant");
+	else if (info == "auxiliary1") return tr("Bloc auxiliaire 1");
+	else if (info == "auxiliary2") return tr("Bloc auxiliaire 2");
+	else if (info == "machine-manufacturer-reference") return tr("Référence fabricant machine");
+	else if (info == "location") return tr("Localisation");
+	else if (info == "function") return tr("Fonction");
 	return (info);
 }
 
@@ -379,6 +389,7 @@ TitleBlockTemplatesFilesCollection *QETApp::commonTitleBlockTemplatesCollection(
 		common_tbt_collection_ = new TitleBlockTemplatesFilesCollection(QETApp::commonTitleBlockTemplatesDir());
 		common_tbt_collection_ -> setTitle(tr("Cartouches QET", "title of the title block templates collection provided by QElectroTech"));
 		common_tbt_collection_ -> setProtocol(QETAPP_COMMON_TBT_PROTOCOL);
+		common_tbt_collection_ -> setCollection(QET::QetCollection::Common);
 	}
 	return(common_tbt_collection_);
 }
@@ -392,6 +403,7 @@ TitleBlockTemplatesFilesCollection *QETApp::customTitleBlockTemplatesCollection(
 		custom_tbt_collection_ = new TitleBlockTemplatesFilesCollection(QETApp::customTitleBlockTemplatesDir());
 		custom_tbt_collection_ -> setTitle(tr("Cartouches utilisateur", "title of the user's title block templates collection"));
 		custom_tbt_collection_ -> setProtocol(QETAPP_CUSTOM_TBT_PROTOCOL);
+		custom_tbt_collection_ -> setCollection(QET::QetCollection::Custom);
 	}
 	return(custom_tbt_collection_);
 }
@@ -402,14 +414,14 @@ TitleBlockTemplatesFilesCollection *QETApp::customTitleBlockTemplatesCollection(
 */
 QList<TitleBlockTemplatesCollection *> QETApp::availableTitleBlockTemplatesCollections() {
 	QList<TitleBlockTemplatesCollection *> collections_list;
-	
+
 	collections_list << common_tbt_collection_;
 	collections_list << custom_tbt_collection_;
-	
+
 	foreach(QETProject *opened_project, registered_projects_) {
 		collections_list << opened_project -> embeddedTitleBlockTemplatesCollection();
 	}
-	
+
 	return(collections_list);
 }
 
@@ -624,14 +636,14 @@ QStringList QETApp::handledFiles(const QList<QUrl> &urls) {
 */
 QETDiagramEditor *QETApp::diagramEditorForFile(const QString &filepath) {
 	if (filepath.isEmpty()) return(0);
-	
+
 	QETApp *qet_app(QETApp::instance());
 	foreach (QETDiagramEditor *diagram_editor, qet_app -> diagramEditors()) {
 		if (diagram_editor -> viewForFile(filepath)) {
 			return(diagram_editor);
 		}
 	}
-	
+
 	return(0);
 }
 
@@ -732,21 +744,20 @@ bool QETApp::closeEveryEditor() {
 }
 
 /**
-	@param size taille voulue - si aucune taille n'est specifiee, la valeur
-	specifiee dans la configuration (diagramsize) est utilisee. La valeur par
-	defaut est 9.
-	@return la police a utiliser pour rendre les textes sur les schemas
-	La famille "Sans Serif" est utilisee par defaut mais peut etre surchargee
-	dans la configuration (diagramfont).
-*/
-QFont QETApp::diagramTextsFont(qreal size) {
-	// acces a la configuration de l'application
-	QSettings &qet_settings = QETApp::settings();
-	
-	// police a utiliser pour le rendu de texte
-	QString diagram_texts_family = qet_settings.value("diagramfont", "Sans Serif").toString();
-	qreal diagram_texts_size     = qet_settings.value("diagramsize", 9.0).toDouble();
-	
+ * @brief QETApp::diagramTextsFont
+ * The font to use
+ * By default the font is "sans Serif" and size 9.
+ * @param size : the size of font
+ * @return the font to use
+ */
+QFont QETApp::diagramTextsFont(qreal size)
+{
+	QSettings settings;
+
+		//Font to use
+	QString diagram_texts_family = settings.value("diagramfont", "Sans Serif").toString();
+	qreal diagram_texts_size     = settings.value("diagramsize", 9.0).toDouble();
+
 	if (size != -1.0) {
 		diagram_texts_size = size;
 	}
@@ -787,14 +798,14 @@ QList<QETTitleBlockTemplateEditor *> QETApp::titleBlockTemplateEditors() {
 QList<QETTitleBlockTemplateEditor *> QETApp::titleBlockTemplateEditors(QETProject *project) {
 	QList<QETTitleBlockTemplateEditor *> editors;
 	if (!project) return(editors);
-	
+
 	// foreach known template editor
 	foreach (QETTitleBlockTemplateEditor *tbt_editor, titleBlockTemplateEditors()) {
 		if (tbt_editor -> location().parentProject() == project) {
 			editors << tbt_editor;
 		}
 	}
-	
+
 	return(editors);
 }
 
@@ -843,20 +854,20 @@ TitleBlockTemplate *QETApp::defaultTitleBlockTemplate() {
 QList<QETElementEditor *> QETApp::elementEditors(QETProject *project) {
 	QList<QETElementEditor *> editors;
 	if (!project) return(editors);
-	
+
 	// pour chaque editeur d'element...
 	foreach(QETElementEditor *elmt_editor, elementEditors()) {
 		// on recupere l'emplacement de l'element qu'il edite
 		ElementsLocation elmt_editor_loc(elmt_editor -> location());
-		
+
 		// il se peut que l'editeur edite un element non enregistre ou un fichier
 		if (elmt_editor_loc.isNull()) continue;
-		
+
 		if (elmt_editor_loc.project() == project) {
 			editors << elmt_editor;
 		}
 	}
-	
+
 	return(editors);
 }
 
@@ -943,9 +954,9 @@ void QETApp::invertMainWindowVisibility(QWidget *window) {
 	Autodetec Windows style
 	@param Windows style
 */
-#if defined(Q_WS_WIN) && defined(Q_WS_WINCE)
+#if defined(Q_OS_WIN) && defined(Q_OS_WINCE)
 
-if defined(Q_WS_WIN)
+if defined(Q_OS_WIN)
 			if ((QSysInfo::WindowsVersion >= QSysInfo::WV_VISTA
 				&& QSysInfo::WindowsVersion < QSysInfo::WV_NT_based))
 				style = QLatin1String("WindowsVista");
@@ -1024,7 +1035,7 @@ void QETApp::messageReceived(const QString &message) {
 
 /**
 	Ouvre les fichiers passes en arguments
-	@param args Objet contenant des arguments ; les fichiers 
+	@param args Objet contenant des arguments ; les fichiers
 	@see openProjectFiles openElementFiles
 */
 void QETApp::openFiles(const QETArguments &args) {
@@ -1043,17 +1054,17 @@ void QETApp::openFiles(const QETArguments &args) {
 */
 void QETApp::openProjectFiles(const QStringList &files_list) {
 	if (files_list.isEmpty()) return;
-	
+
 	// liste des editeurs de schema ouverts
 	QList<QETDiagramEditor *> diagrams_editors = diagramEditors();
-	
+
 	// s'il y a des editeur de schemas ouvert, on cherche ceux qui sont visibles
 	if (diagrams_editors.count()) {
 		QList<QETDiagramEditor *> visible_diagrams_editors;
 		foreach(QETDiagramEditor *de, diagrams_editors) {
 			if (de -> isVisible()) visible_diagrams_editors << de;
 		}
-		
+
 		// on choisit soit le premier visible soit le premier tout court
 		QETDiagramEditor *de_open;
 		if (visible_diagrams_editors.count()) {
@@ -1062,7 +1073,7 @@ void QETApp::openProjectFiles(const QStringList &files_list) {
 			de_open = diagrams_editors.first();
 			de_open -> setVisible(true);
 		}
-		
+
 		// ouvre les fichiers dans l'editeur ainsi choisi
 		foreach(QString file, files_list) {
 			de_open -> openAndAddProject(file);
@@ -1080,7 +1091,7 @@ void QETApp::openProjectFiles(const QStringList &files_list) {
 */
 void QETApp::openElementFiles(const QStringList &files_list) {
 	if (files_list.isEmpty()) return;
-	
+
 	// evite autant que possible les doublons dans la liste fournie
 	QSet<QString> files_set;
 	foreach(QString file, files_list) {
@@ -1089,10 +1100,10 @@ void QETApp::openElementFiles(const QStringList &files_list) {
 	}
 	// a ce stade, tous les fichiers dans le Set existent et sont a priori differents
 	if (files_set.isEmpty()) return;
-	
+
 	// liste des editeurs d'element ouverts
 	QList<QETElementEditor *> element_editors = elementEditors();
-	
+
 	// on traite les fichiers a la queue leu leu...
 	foreach(QString element_file, files_set) {
 		bool already_opened_in_existing_element_editor = false;
@@ -1121,10 +1132,10 @@ void QETApp::openElementFiles(const QStringList &files_list) {
 */
 void QETApp::openElementLocations(const QList<ElementsLocation> &locations_list) {
 	if (locations_list.isEmpty()) return;
-	
+
 	// liste des editeurs d'element ouverts
 	QList<QETElementEditor *> element_editors = elementEditors();
-	
+
 	// on traite les emplacements  a la queue leu leu...
 	foreach(ElementsLocation element_location, locations_list) {
 		bool already_opened_in_existing_element_editor = false;
@@ -1149,7 +1160,7 @@ void QETApp::openElementLocations(const QList<ElementsLocation> &locations_list)
 /**
 	Launch a new title block template editor to edit the given template
 	@param location location of the title block template to be edited
-	
+
 	@param duplicate if true, the template is opened for duplication, which means
 	the user will be prompter for a new template name.
 	@see QETTitleBlockTemplateEditor::setOpenForDuplication()
@@ -1178,7 +1189,7 @@ void QETApp::openTitleBlockTemplate(const QString &filepath) {
 */
 void QETApp::openTitleBlockTemplateFiles(const QStringList &files_list) {
 	if (files_list.isEmpty()) return;
-	
+
 	// avoid duplicates in the provided files list
 	QSet<QString> files_set;
 	foreach (QString file, files_list) {
@@ -1187,10 +1198,10 @@ void QETApp::openTitleBlockTemplateFiles(const QStringList &files_list) {
 	}
 	// here, we can assume all files in the set exist and are different
 	if (files_set.isEmpty()) return;
-	
+
 	// opened title block template editors
 	QList<QETTitleBlockTemplateEditor *> tbt_editors = titleBlockTemplateEditors();
-	
+
 	foreach(QString tbt_file, files_set) {
 		bool already_opened_in_existing_tbt_editor = false;
 		foreach(QETTitleBlockTemplateEditor *tbt_editor, tbt_editors) {
@@ -1217,7 +1228,7 @@ void QETApp::openTitleBlockTemplateFiles(const QStringList &files_list) {
 void QETApp::configureQET() {
 	// determine le widget parent a utiliser pour le dialogue
 	QWidget *parent_widget = activeWindow();
-	
+
 	// cree le dialogue
 	ConfigDialog cd;
 	cd.setWindowTitle(tr("Configurer QElectroTech", "window title"));
@@ -1225,13 +1236,13 @@ void QETApp::configureQET() {
 	cd.addPage(new NewDiagramPage());
 	cd.addPage(new ExportConfigPage());
 	cd.addPage(new PrintConfigPage());
-	
-	
+
+
 	// associe le dialogue a un eventuel widget parent
 	if (parent_widget) {
 		cd.setParent(parent_widget, cd.windowFlags());
 	}
-	
+
 	// affiche le dialogue puis evite de le lier a un quelconque widget parent
 	cd.exec();
 	cd.setParent(0, cd.windowFlags());
@@ -1247,20 +1258,20 @@ void QETApp::configureQET() {
 void QETApp::aboutQET() {
 	// determine le widget parent a utiliser pour le dialogue
 	QWidget *parent_widget = activeWindow();
-	
+
 	// cree le dialogue si cela n'a pas deja ete fait
 	if (!about_dialog_) {
 		about_dialog_ = new AboutQET();
 	}
-	
+
 	// associe le dialogue a un eventuel widget parent
 	if (parent_widget) {
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 		about_dialog_ -> setWindowFlags(Qt::Sheet);
 #endif
 		about_dialog_ -> setParent(parent_widget, about_dialog_ -> windowFlags());
 	}
-	
+
 	// affiche le dialogue puis evite de le lier a un quelconque widget parent
 	about_dialog_ -> exec();
 	about_dialog_ -> setParent(0, about_dialog_ -> windowFlags());
@@ -1296,13 +1307,13 @@ QList<QWidget *> QETApp::floatingToolbarsAndDocksForMainWindow(QMainWindow *wind
 void QETApp::parseArguments() {
 	// recupere les arguments
 	QList<QString> arguments_list(arguments());
-	
+
 	// enleve le premier argument : il s'agit du fichier binaire
 	arguments_list.takeFirst();
-	
+
 	// analyse les arguments
 	qet_arguments_ = QETArguments(arguments_list);
-	
+
 #ifdef QET_ALLOW_OVERRIDE_CED_OPTION
 	if (qet_arguments_.commonElementsDirSpecified()) {
 		overrideCommonElementsDir(qet_arguments_.commonElementsDir());
@@ -1318,11 +1329,11 @@ void QETApp::parseArguments() {
 		overrideConfigDir(qet_arguments_.configDir());
 	}
 #endif
-	
+
 	if (qet_arguments_.langDirSpecified()) {
 		overrideLangDir(qet_arguments_.langDir());
 	}
-	
+
 	if (qet_arguments_.printLicenseRequested()) {
 		printLicense();
 		non_interactive_execution_ = true;
@@ -1369,18 +1380,20 @@ void QETApp::initLanguage() {
 }
 
 /**
-	Met en place tout ce qui concerne le style graphique de l'application
-*/
+ * @brief QETApp::initStyle
+ * Setup the gui style
+ */
 void QETApp::initStyle() {
 	initial_palette_ = palette();
-	
-	// lorsque le style Plastique est active, on le remplace par une version amelioree
-	if (qobject_cast<QPlastiqueStyle *>(style())) {
-		setStyle(new QETStyle());
-	}
-	
-	// applique ou non les couleurs de l'environnement
-	useSystemPalette(settings().value("usesystemcolors", true).toBool());
+
+	//@TODO remove the code below
+//	// lorsque le style Plastique est active, on le remplace par une version amelioree
+//	if (qobject_cast<QPlastiqueStyle *>(style())) {
+//		setStyle(new QETStyle());
+//	}
+		//Apply or not the system style
+	QSettings settings;
+	useSystemPalette(settings.value("usesystemcolors", true).toBool());
 }
 
 /**
@@ -1394,16 +1407,13 @@ void QETApp::initConfiguration() {
 	// cree les dossiers de configuration si necessaire
 	QDir config_dir(QETApp::configDir());
 	if (!config_dir.exists()) config_dir.mkpath(QETApp::configDir());
-	
+
 	QDir custom_elements_dir(QETApp::customElementsDir());
 	if (!custom_elements_dir.exists()) custom_elements_dir.mkpath(QETApp::customElementsDir());
-	
+
 	QDir custom_tbt_dir(QETApp::customTitleBlockTemplatesDir());
 	if (!custom_tbt_dir.exists()) custom_tbt_dir.mkpath(QETApp::customTitleBlockTemplatesDir());
-	
-	// lit le fichier de configuration
-	qet_settings = new QSettings(configDir() + "qelectrotech.conf", QSettings::IniFormat, this);
-	
+
 	// fichiers recents
 	// note : les icones doivent etre initialisees avant ces instructions (qui creent des menus en interne)
 	projects_recent_files_ = new RecentFiles("projects");
@@ -1416,26 +1426,26 @@ void QETApp::initConfiguration() {
 	Construit l'icone dans le systray et son menu
 */
 void QETApp::initSystemTray() {
-	setSplashScreenStep(tr("Chargement... ic\364ne du systray", "splash screen caption"));
+	setSplashScreenStep(tr("Chargement... icône du systray", "splash screen caption"));
 	// initialisation des menus de l'icone dans le systray
 	menu_systray = new QMenu(tr("QElectroTech", "systray menu title"));
-	
+
 	quitter_qet       = new QAction(QET::Icons::ApplicationExit,       tr("&Quitter"),                                        this);
 	reduce_appli      = new QAction(QET::Icons::Hide,    tr("&Masquer"),                                        this);
 	restore_appli     = new QAction(QET::Icons::Restore,  tr("&Restaurer"),                                      this);
-	reduce_diagrams   = new QAction(QET::Icons::Hide,    tr("&Masquer tous les \351diteurs de sch\351ma"),      this);
-	restore_diagrams  = new QAction(QET::Icons::Restore,  tr("&Restaurer tous les \351diteurs de sch\351ma"),    this);
-	reduce_elements   = new QAction(QET::Icons::Hide,    tr("&Masquer tous les \351diteurs d'\351l\351ment"),   this);
-	restore_elements  = new QAction(QET::Icons::Restore,  tr("&Restaurer tous les \351diteurs d'\351l\351ment"), this);
-	reduce_templates  = new QAction(QET::Icons::Hide,      tr("&Masquer tous les \351diteurs de cartouche",   "systray submenu entry"), this);
-	restore_templates = new QAction(QET::Icons::Restore,   tr("&Restaurer tous les \351diteurs de cartouche", "systray submenu entry"), this);
-	new_diagram       = new QAction(QET::Icons::WindowNew, tr("&Nouvel \351diteur de sch\351ma"),                 this);
-	new_element       = new QAction(QET::Icons::WindowNew, tr("&Nouvel \351diteur d'\351l\351ment"),              this);
-	
+	reduce_diagrams   = new QAction(QET::Icons::Hide,    tr("&Masquer tous les éditeurs de schéma"),      this);
+	restore_diagrams  = new QAction(QET::Icons::Restore,  tr("&Restaurer tous les éditeurs de schéma"),    this);
+	reduce_elements   = new QAction(QET::Icons::Hide,    tr("&Masquer tous les éditeurs d'élément"),   this);
+	restore_elements  = new QAction(QET::Icons::Restore,  tr("&Restaurer tous les éditeurs d'élément"), this);
+	reduce_templates  = new QAction(QET::Icons::Hide,      tr("&Masquer tous les éditeurs de cartouche",   "systray submenu entry"), this);
+	restore_templates = new QAction(QET::Icons::Restore,   tr("&Restaurer tous les éditeurs de cartouche", "systray submenu entry"), this);
+	new_diagram       = new QAction(QET::Icons::WindowNew, tr("&Nouvel éditeur de schéma"),                 this);
+	new_element       = new QAction(QET::Icons::WindowNew, tr("&Nouvel éditeur d'élément"),              this);
+
 	quitter_qet   -> setStatusTip(tr("Ferme l'application QElectroTech"));
-	reduce_appli  -> setToolTip(tr("R\351duire QElectroTech dans le systray"));
+	reduce_appli  -> setToolTip(tr("Réduire QElectroTech dans le systray"));
 	restore_appli -> setToolTip(tr("Restaurer QElectroTech"));
-	
+
 	connect(quitter_qet,      SIGNAL(triggered()), this, SLOT(quitQET()));
 	connect(reduce_appli,     SIGNAL(triggered()), this, SLOT(reduceEveryEditor()));
 	connect(restore_appli,    SIGNAL(triggered()), this, SLOT(restoreEveryEditor()));
@@ -1447,7 +1457,7 @@ void QETApp::initSystemTray() {
 	connect(restore_templates,SIGNAL(triggered()), this, SLOT(restoreTitleBlockTemplateEditors()));
 	connect(new_diagram,      SIGNAL(triggered()), this, SLOT(newDiagramEditor()));
 	connect(new_element,      SIGNAL(triggered()), this, SLOT(newElementEditor()));
-	
+
 	// initialisation de l'icone du systray
 	qsti = new QSystemTrayIcon(QET::Icons::QETLogo, this);
 	qsti -> setToolTip(tr("QElectroTech", "systray icon tooltip"));
@@ -1508,27 +1518,27 @@ QETProject *QETApp::projectFromString(const QString &url) {
 /// construit le menu de l'icone dans le systray
 void QETApp::buildSystemTrayMenu() {
 	menu_systray -> clear();
-	
+
 	// recupere les editeurs
 	QList<QETDiagramEditor *> diagrams = diagramEditors();
 	QList<QETElementEditor *> elements = elementEditors();
 	QList<QETTitleBlockTemplateEditor *> tbtemplates = titleBlockTemplateEditors();
 	fetchWindowStats(diagrams, elements, tbtemplates);
-	
+
 	// ajoute le bouton reduire / restaurer au menu
 	menu_systray -> addAction(every_editor_reduced ? restore_appli : reduce_appli);
-	
+
 	// ajoute les editeurs de schemas dans un sous-menu
-	QMenu *diagrams_submenu = menu_systray -> addMenu(tr("\311diteurs de sch\351mas"));
+	QMenu *diagrams_submenu = menu_systray -> addMenu(tr("Éditeurs de schémas"));
 	diagrams_submenu -> addAction(reduce_diagrams);
 	diagrams_submenu -> addAction(restore_diagrams);
 	diagrams_submenu -> addAction(new_diagram);
 	reduce_diagrams -> setEnabled(!diagrams.isEmpty() && !every_diagram_reduced);
 	restore_diagrams -> setEnabled(!diagrams.isEmpty() && !every_diagram_visible);
 	addWindowsListToMenu<QETDiagramEditor>(diagrams_submenu, diagrams);
-	
+
 	// ajoute les editeurs d'elements au menu
-	QMenu *elements_submenu = menu_systray -> addMenu(tr("\311diteurs d'\351l\351ment"));
+	QMenu *elements_submenu = menu_systray -> addMenu(tr("Éditeurs d'élément"));
 	elements_submenu -> addAction(reduce_elements);
 	elements_submenu -> addAction(restore_elements);
 	elements_submenu -> addAction(new_element);
@@ -1536,15 +1546,15 @@ void QETApp::buildSystemTrayMenu() {
 	restore_elements -> setEnabled(!elements.isEmpty() && !every_element_visible);
 	elements_submenu -> addSeparator();
 	addWindowsListToMenu<QETElementEditor>(elements_submenu, elements);
-	
+
 	// add title block template editors in a submenu
-	QMenu *tbtemplates_submenu = menu_systray -> addMenu(tr("\311diteurs de cartouche", "systray menu entry"));
+	QMenu *tbtemplates_submenu = menu_systray -> addMenu(tr("Éditeurs de cartouche", "systray menu entry"));
 	tbtemplates_submenu -> addAction(reduce_templates);
 	tbtemplates_submenu -> addAction(restore_templates);
 	reduce_templates  -> setEnabled(!tbtemplates.isEmpty() && !every_template_reduced);
 	restore_templates -> setEnabled(!tbtemplates.isEmpty() && !every_template_visible);
 	addWindowsListToMenu<QETTitleBlockTemplateEditor>(tbtemplates_submenu, tbtemplates);
-	
+
 	// ajoute le bouton quitter au menu
 	menu_systray -> addSeparator();
 	menu_systray -> addAction(quitter_qet);
@@ -1561,13 +1571,13 @@ void QETApp::fetchWindowStats(
 	foreach(QMainWindow *w, diagrams) if (w -> isVisible()) ++ visible_diagrams;
 	every_diagram_reduced = !visible_diagrams;
 	every_diagram_visible = visible_diagrams == diagrams.count();
-	
+
 	// compte le nombre de schemas visibles
 	int visible_elements = 0;
 	foreach(QMainWindow *w, elements) if (w -> isVisible()) ++ visible_elements;
 	every_element_reduced = !visible_elements;
 	every_element_visible = visible_elements == elements.count();
-	
+
 	// count visible template editors
 	int visible_templates = 0;
 	foreach(QMainWindow *window, tbtemplates) {
@@ -1575,7 +1585,7 @@ void QETApp::fetchWindowStats(
 	}
 	every_template_reduced = !visible_templates;
 	every_template_visible = visible_templates == tbtemplates.count();
-	
+
 	// determine si tous les elements sont reduits
 	every_editor_reduced = every_element_reduced && every_diagram_reduced;
 }
@@ -1604,7 +1614,7 @@ bool QETApp::event(QEvent *e) {
 void QETApp::printHelp() {
 	QString help(
 		tr("Usage : ") + QFileInfo(applicationFilePath()).fileName() + tr(" [options] [fichier]...\n\n") +
-		tr("QElectroTech, une application de r\351alisation de sch\351mas \351lectriques.\n\n"
+		tr("QElectroTech, une application de réalisation de schémas électriques.\n\n"
 		"Options disponibles : \n"
 		"  --help                        Afficher l'aide sur les options\n"
 		"  -v, --version                 Afficher la version\n"
@@ -1637,55 +1647,51 @@ void QETApp::printLicense() {
 	std::cout << qPrintable(QET::license()) << std::endl;
 }
 
-/// Constructeur
-QETStyle::QETStyle() : QPlastiqueStyle() {
-}
+//@TODO remove code below
+///// Constructeur
+//QETStyle::QETStyle() : QPlastiqueStyle() {
+//}
 
-/// Destructeur
-QETStyle::~QETStyle() {
-}
+///// Destructeur
+//QETStyle::~QETStyle() {
+//}
 
-/// Gere les parametres de style
-int QETStyle::styleHint(StyleHint hint, const QStyleOption *option, const QWidget *widget, QStyleHintReturn *returndata) const {
-	if (hint == QStyle::SH_DialogButtonBox_ButtonsHaveIcons) {
-		return(int(true));
-	} else {
-		return(QPlastiqueStyle::styleHint(hint, option, widget, returndata));
-	}
-}
+///// Gere les parametres de style
+//int QETStyle::styleHint(StyleHint hint, const QStyleOption *option, const QWidget *widget, QStyleHintReturn *returndata) const {
+//	if (hint == QStyle::SH_DialogButtonBox_ButtonsHaveIcons) {
+//		return(int(true));
+//	} else {
+//		return(QPlastiqueStyle::styleHint(hint, option, widget, returndata));
+//	}
+//}
 
-/// Gere les icones standard
-QIcon QETStyle::standardIconImplementation(StandardPixmap standardIcon, const QStyleOption *option, const QWidget* widget) const {
-	switch(standardIcon) {
-		case QStyle::SP_DialogSaveButton:
-			return(QET::Icons::DocumentSave);
-		case QStyle::SP_DialogOpenButton:
-			return(QET::Icons::DocumentOpen);
-		case QStyle::SP_DialogCancelButton:
-			return(QET::Icons::DialogCancel);
-		case QStyle::SP_DialogOkButton:
-		case QStyle::SP_DialogApplyButton:
-			return(QET::Icons::DialogOk);
-		case QStyle::SP_DialogCloseButton:
-			return(QET::Icons::DocumentClose);
-		case QStyle::SP_DialogYesButton:
-			return(QET::Icons::Allowed);
-		case QStyle::SP_DialogNoButton:
-			return(QET::Icons::Forbidden);
-		case QStyle::SP_DialogResetButton:
-			return(QET::Icons::EditUndo);
-		case QStyle::SP_DialogHelpButton:
-		case QStyle::SP_DialogDiscardButton:
-			return(QIcon());
-		default:
-			return(QPlastiqueStyle::standardIconImplementation(standardIcon, option, widget));
-	}
-}
-
-/// @return une reference vers les parametres de QElectroTEch
-QSettings &QETApp::settings() {
-	return(*(instance() -> qet_settings));
-}
+///// Gere les icones standard
+//QIcon QETStyle::standardIconImplementation(StandardPixmap standardIcon, const QStyleOption *option, const QWidget* widget) const {
+//	switch(standardIcon) {
+//		case QStyle::SP_DialogSaveButton:
+//			return(QET::Icons::DocumentSave);
+//		case QStyle::SP_DialogOpenButton:
+//			return(QET::Icons::DocumentOpen);
+//		case QStyle::SP_DialogCancelButton:
+//			return(QET::Icons::DialogCancel);
+//		case QStyle::SP_DialogOkButton:
+//		case QStyle::SP_DialogApplyButton:
+//			return(QET::Icons::DialogOk);
+//		case QStyle::SP_DialogCloseButton:
+//			return(QET::Icons::DocumentClose);
+//		case QStyle::SP_DialogYesButton:
+//			return(QET::Icons::Allowed);
+//		case QStyle::SP_DialogNoButton:
+//			return(QET::Icons::Forbidden);
+//		case QStyle::SP_DialogResetButton:
+//			return(QET::Icons::EditUndo);
+//		case QStyle::SP_DialogHelpButton:
+//		case QStyle::SP_DialogDiscardButton:
+//			return(QIcon());
+//		default:
+//			return(QPlastiqueStyle::standardIconImplementation(standardIcon, option, widget));
+//	}
+//}
 
 /**
 	@param location adresse virtuelle d'un item (collection, categorie, element, ...)
@@ -1758,10 +1764,10 @@ QMap<uint, QETProject *> QETApp::registeredProjects() {
 bool QETApp::registerProject(QETProject *project) {
 	// le projet doit sembler valide
 	if (!project) return(false);
-	
+
 	// si le projet est deja enregistre, renvoie false
 	if (projectId(project) != -1) return(false);
-	
+
 	// enregistre le projet
 	registered_projects_.insert(next_project_id ++, project);
 	return(true);
@@ -1775,10 +1781,10 @@ bool QETApp::registerProject(QETProject *project) {
 */
 bool QETApp::unregisterProject(QETProject *project) {
 	int project_id = projectId(project);
-	
+
 	// si le projet n'est pas enregistre, renvoie false
 	if (project_id == -1) return(false);
-	
+
 	// annule l'enregistrement du projet
 	return(registered_projects_.remove(project_id) == 1);
 }
