@@ -117,9 +117,9 @@ bool CustomElement::buildFromXml(const QDomElement &xml_def_elmt, int *state) {
 		qreal element_version = xml_def_elmt.attribute("version").toDouble(&conv_ok);
 		if (conv_ok && QET::version.toDouble() < element_version) {
 			std::cerr << qPrintable(
-				QObject::tr("Avertissement : l'\351l\351ment "
-				" a \351t\351 enregistr\351 avec une version"
-				" ult\351rieure de QElectroTech.")
+				QObject::tr("Avertissement : l'élément "
+				" a été enregistré avec une version"
+				" ultérieure de QElectroTech.")
 			) << std::endl;
 		}
 	}
@@ -674,14 +674,8 @@ bool CustomElement::parseText(QDomElement &e, QPainter &qp) {
 	*/
 	QPointF qpainter_offset(0.0, -qfm.ascent());
 	
-	// ajuste le decalage selon la marge du document texte
-#if QT_VERSION >= 0x040500
+		//adjusts the offset by the margin of the text document
 	text_document.setDocumentMargin(0.0);
-#else
-	// il semblerait qu'avant Qt 4.5, le documentMargin vaille 2.0 (et pas 4.0)
-	qpainter_offset.rx() -= 2.0;
-	qpainter_offset.ry() -= 2.0;
-#endif
 	
 	qp.translate(qpainter_offset);
 	
@@ -822,6 +816,13 @@ bool CustomElement::validOrientationAttribute(const QDomElement &e) {
 			 - red   : remplissage rouge
 			- blue  : remplissage bleu
 			- green : remplissage vert
+			- gray : remplissage gris
+			- brun : remplissage marron
+			- yellow : remplissage jaune
+			- cyan : remplissage cyan
+			- lightgray : remplissage gris clair
+			- orange : remplissage orange
+			- purple : remplissage violet
 			- none : pas de remplissage [par defaut]
 		- color : couleur du trait et du texte
 			- white : trait noir [par defaut]
@@ -829,6 +830,18 @@ bool CustomElement::validOrientationAttribute(const QDomElement &e) {
 			- red   : trait rouge
 			- blue  : trait bleu
 			- green : trait vert
+			- gray : trait gris
+			- brun : trait marron
+			- yellow : trait jaune
+			- cyan : trait cyan
+			- lightgray : trait gris clair
+			- orange : trait orange
+			- purple : trait violet
+			- lignes Horizontales
+			- lignes Verticales
+			- hachures gauche
+			- hachures  droite
+			- none : pas de contour
 			
 	Les autres valeurs ne sont pas prises en compte.
 	@param e L'element XML a parser
@@ -880,6 +893,42 @@ void CustomElement::setPainterStyle(QDomElement &e, QPainter &qp) {
 				} else if (style_value == "green") {
 					brush.setStyle(Qt::SolidPattern);
 					brush.setColor(Qt::green);
+				} else if (style_value == "gray") {
+					brush.setStyle(Qt::SolidPattern);
+					brush.setColor(Qt::gray);
+				} else if (style_value == "brun") {
+					brush.setStyle(Qt::SolidPattern);
+					brush.setColor(QColor(97, 44, 0));
+				} else if (style_value == "yellow") {
+					brush.setStyle(Qt::SolidPattern);
+					brush.setColor(Qt::yellow);
+				} else if (style_value == "cyan") {
+					brush.setStyle(Qt::SolidPattern);
+					brush.setColor(Qt::cyan);
+				} else if (style_value == "magenta") {
+					brush.setStyle(Qt::SolidPattern);
+					brush.setColor(Qt::magenta);
+				} else if (style_value == "lightgray") {
+					brush.setStyle(Qt::SolidPattern);
+					brush.setColor(Qt::lightGray);
+				} else if (style_value == "orange") {
+					brush.setStyle(Qt::SolidPattern);
+					brush.setColor(QColor(255, 128, 0));
+				} else if (style_value == "purple") {
+					brush.setStyle(Qt::SolidPattern);
+					brush.setColor(QColor(136, 28, 168));
+				}else if (style_value == "hor") {
+					brush.setStyle(Qt::HorPattern);
+					brush.setColor(Qt::black);
+				} else if (style_value == "ver") {
+					brush.setStyle(Qt::VerPattern);
+					brush.setColor(Qt::black);
+				} else if (style_value == "bdiag") {
+					brush.setStyle(Qt::BDiagPattern);
+					brush.setColor(Qt::black);
+				} else if (style_value == "fdiag") {
+					brush.setStyle(Qt::FDiagPattern);
+					brush.setColor(Qt::black);
 				} else if (style_value == "none") {
 					brush.setStyle(Qt::NoBrush);
 				}
@@ -894,6 +943,24 @@ void CustomElement::setPainterStyle(QDomElement &e, QPainter &qp) {
 					pen.setColor(Qt::blue);
 				}else if (style_value == "green") {
 					pen.setColor(Qt::green);
+				}else if (style_value == "gray") {
+					pen.setColor(Qt::gray);
+				}else if (style_value == "brun") {
+					pen.setColor(QColor(97, 44, 0));
+				}else if (style_value == "yellow") {
+					pen.setColor(Qt::yellow);
+				}else if (style_value == "cyan") {
+					pen.setColor(Qt::cyan);
+				}else if (style_value == "magenta") {
+					pen.setColor(Qt::magenta);
+				}else if (style_value == "lightgray") {
+					pen.setColor(Qt::lightGray);
+				}else if (style_value == "orange") {
+					pen.setColor(QColor(255, 128, 0));
+				}else if (style_value == "purple") {
+					pen.setColor(QColor(136, 28, 168));
+				} else if (style_value == "none") {
+					pen.setBrush(Qt::transparent);
 				}
 			}
 		}
