@@ -16,16 +16,16 @@
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "element.h"
-#include "qetapp.h"
 #include "diagram.h"
 #include "conductor.h"
 #include "elementtextitem.h"
 #include "diagramcommands.h"
 #include <QtDebug>
-#include <ui/elementpropertieswidget.h>
 #include "elementprovider.h"
 #include "diagramposition.h"
 #include "terminal.h"
+#include "PropertiesEditor/propertieseditordialog.h"
+#include "elementpropertieswidget.h"
 
 /**
 	Constructeur pour un element sans scene ni parent
@@ -39,7 +39,7 @@ Element::Element(QGraphicsItem *parent) :
 	uuid_ = QUuid::createUuid();
 	setZValue(10);
 	setFlags(QGraphicsItem::ItemIsMovable | QGraphicsItem::ItemIsSelectable);
-	setAcceptsHoverEvents(true);
+	setAcceptHoverEvents(true);
 }
 
 /**
@@ -48,14 +48,15 @@ Element::Element(QGraphicsItem *parent) :
 Element::~Element() {
 }
 
-void Element::editProperty() {
-	if (diagram())
-		if(!diagram()->isReadOnly()){
-			elementpropertieswidget epw (this, diagram()->views().first());
-			connect(&epw, SIGNAL(editElementRequired(ElementsLocation)), diagram(), SIGNAL(editElementRequired(ElementsLocation)));
-			connect(&epw, SIGNAL(findElementRequired(ElementsLocation)), diagram(), SIGNAL(findElementRequired(ElementsLocation)));
-			epw.exec();
-		}
+void Element::editProperty()
+{
+	if (diagram() && !diagram()->isReadOnly())
+	{
+		ElementPropertiesWidget *epw = new ElementPropertiesWidget(this);
+		PropertiesEditorDialog dialog(epw, QApplication::activeWindow());
+		connect(epw, &ElementPropertiesWidget::findEditClicked, &dialog, &QDialog::reject);
+		dialog.exec();
+	}
 }
 
 
@@ -76,27 +77,25 @@ void Element::setHighlighted(bool hl) {
 }
 
 /**
-	Methode principale de dessin de l'element
-	@param painter Le QPainter utilise pour dessiner l'elment
-	@param options Les options de style a prendre en compte
-	@param widget  Le widget sur lequel on dessine
-*/
-void Element::paint(QPainter *painter, const QStyleOptionGraphicsItem *options, QWidget *widget) {
-	
-#ifndef Q_WS_WIN
-	// corrige un bug de rendu ne se produisant que lors du rendu sur QGraphicsScene sous X11 au zoom par defaut
-	static bool must_correct_rendering_bug = QETApp::settings().value("correct-rendering", false).toBool();
-	if (must_correct_rendering_bug) {
-		Diagram *dia = diagram();
-		if (dia && options -> levelOfDetail == 1.0 && widget) {
-			// calcule la rotation qu'a subi l'element
-			qreal applied_rotation = 90.0 * orientation();
-			if (applied_rotation == 90.0) painter -> translate(1.0, -1.0);
-			else if (applied_rotation == 180.0) painter -> translate(-1.0, -1.0);
-			else if (applied_rotation == 270.0) painter -> translate(-1.0, 1.0);
-		}
-	}
-#endif
+ * @brief Element::displayHelpLine
+ * Display the help line of each terminal if b is true
+ * @param b
+ */
+void Element::displayHelpLine(bool b)
+{
+	foreach (Terminal *t, terminals())
+		t->drawHelpLine(b);
+}
+
+/**
+ * @brief Element::paint
+ * @param painter
+ * @param options
+ * @param widget
+ */
+void Element::paint(QPainter *painter, const QStyleOptionGraphicsItem *options, QWidget *)
+{
+
 	if (must_highlight_) drawHighlight(painter, options);
 	
 		//Draw the element himself
@@ -256,6 +255,7 @@ void Element::drawSelection(QPainter *painter, const QStyleOptionGraphicsItem *o
 	QPen t;
 	t.setColor(Qt::gray);
 	t.setStyle(Qt::DashDotLine);
+	t.setCosmetic(true);
 	painter -> setPen(t);
 	// Le dessin se fait a partir du rectangle delimitant
 	painter -> drawRoundRect(boundingRect().adjusted(1, 1, -1, -1), 10, 10);
@@ -403,10 +403,11 @@ bool Element::fromXml(QDomElement &e, QHash<int, Terminal *> &table_id_adr, bool
 	uuid_= QUuid(e.attribute("uuid", QUuid::createUuid().toString()));
 
 	//load informations
-	element_informations_.fromXml(e.firstChildElement("elementInformations"), "elementInformation");
+	m_element_informations.fromXml(e.firstChildElement("elementInformations"), "elementInformation");
 
-	// position, selection
-	setPos(e.attribute("x").toDouble(), e.attribute("y").toDouble());
+		//Position and selection.
+		//We directly call setPos from QGraphicsObject, because QetGraphicsItem will snap to grid
+	QGraphicsObject::setPos(e.attribute("x").toDouble(), e.attribute("y").toDouble());
 	setFlags(QGraphicsItem::ItemIsMovable | QGraphicsItem::ItemIsSelectable);
 	
 	// orientation
@@ -485,9 +486,9 @@ QDomElement Element::toXml(QDomDocument &document, QHash<Terminal *, int> &table
 	}
 
 	//save information of this element
-	if (! element_informations_.keys().isEmpty()) {
+	if (! m_element_informations.keys().isEmpty()) {
 		QDomElement infos = document.createElement("elementInformations");
-		element_informations_.toXml(infos, "elementInformation");
+		m_element_informations.toXml(infos, "elementInformation");
 		element.appendChild(infos);
 	}
 
@@ -543,13 +544,15 @@ void Element::initLink(QETProject *prj)
 /**
  * @brief Element::setElementInformations
  * Set new information for this element.
- * This method emit @elementInfoChange
+ * If new information is different of current infotmation emit @elementInfoChange
  * @param dc
  */
-void Element::setElementInformations(DiagramContext dc) {
-	DiagramContext old_info = element_informations_;
-	element_informations_ = dc;
-	emit elementInfoChange(old_info, element_informations_);
+void Element::setElementInformations(DiagramContext dc)
+{
+	if (m_element_informations == dc) return;
+	DiagramContext old_info = m_element_informations;
+	m_element_informations = dc;
+	emit elementInfoChange(old_info, m_element_informations);
 }
 
 /**
