@@ -20,7 +20,6 @@
 #include "qetgraphicsitem/element.h"
 #include "qetgraphicsitem/conductor.h"
 #include "diagramcommands.h"
-#include "qetapp.h"
 #include "conductorautonumerotation.h"
 
 QColor Terminal::neutralColor      = QColor(Qt::blue);
@@ -64,7 +63,7 @@ void Terminal::init(QPointF pf, Qet::Orientation o, QString number, QString name
 	br_ = new QRectF();
 	previous_terminal_ = 0;
 	// divers
-	setAcceptsHoverEvents(true);
+	setAcceptHoverEvents(true);
 	setAcceptedMouseButtons(Qt::LeftButton);
 	hovered_ = false;
 	setToolTip(QObject::tr("Borne", "tooltip"));
@@ -78,7 +77,7 @@ void Terminal::init(QPointF pf, Qet::Orientation o, QString number, QString name
 	@param s   Scene sur laquelle figure cette borne
 */
 Terminal::Terminal(QPointF pf, Qet::Orientation o, Element *e) :
-	QGraphicsItem(e),
+	QGraphicsObject(e),
 	m_draw_help_line(false),
 	m_help_line     (nullptr),
 	m_help_line_a   (nullptr),
@@ -97,7 +96,7 @@ Terminal::Terminal(QPointF pf, Qet::Orientation o, Element *e) :
 	@param s    Scene sur laquelle figure cette borne
 */
 Terminal::Terminal(qreal pf_x, qreal pf_y, Qet::Orientation o, Element *e) :
-	QGraphicsItem(e),
+	QGraphicsObject(e),
 	m_draw_help_line (false),
 	m_help_line      (nullptr),
 	m_help_line_a    (nullptr),
@@ -118,7 +117,7 @@ Terminal::Terminal(qreal pf_x, qreal pf_y, Qet::Orientation o, Element *e) :
 	@param s   Scene sur laquelle figure cette borne
 */
 Terminal::Terminal(QPointF pf, Qet::Orientation o, QString num, QString name, bool hiddenName, Element *e) :
-	QGraphicsItem    (e),
+	QGraphicsObject    (e),
 	m_draw_help_line (false),
 	m_help_line      (nullptr),
 	m_help_line_a    (nullptr),
@@ -179,41 +178,41 @@ void Terminal::setName(QString name, bool hiddenName) {
 }
 
 /**
-	Attribue un conductor a la borne
-	@param f Le conducteur a rattacher a cette borne
-*/
-bool Terminal::addConductor(Conductor *f) {
-	// pointeur 0 refuse
-	if (!f) return(false);
+ * @brief Terminal::addConductor
+ * Add a conductor to this terminal
+ * @param conductor : the conductor to add.
+ * @return true if the conductor was successfully added
+ */
+bool Terminal::addConductor(Conductor *conductor)
+{
+	if (!conductor) return(false);
 	
-	// une seule des deux bornes du conducteur doit etre this
-	Q_ASSERT_X(((f -> terminal1 == this) ^ (f -> terminal2 == this)), "Terminal::addConductor", "Le conductor devrait etre relie exactement une fois a la terminal en cours");
+	Q_ASSERT_X(((conductor -> terminal1 == this) ^ (conductor -> terminal2 == this)), "Terminal::addConductor", "The conductor must be linked exactly once to this terminal");
 	
-	// determine l'autre borne a laquelle cette borne va etre relie grace au conducteur
-	Terminal *autre_terminal = (f -> terminal1 == this) ? f -> terminal2 : f -> terminal1;
+		//Get the other terminal where the conductor must be linked
+	Terminal *other_terminal = (conductor -> terminal1 == this) ? conductor->terminal2 : conductor->terminal1;
 	
-	// verifie que la borne n'est pas deja reliee avec l'autre borne
-	bool deja_liees = false;
-	foreach (Conductor* conductor, conductors_) {
-		if (conductor -> terminal1 == autre_terminal || conductor -> terminal2 == autre_terminal) deja_liees = true;
-	}
-	
-	// si les deux bornes sont deja reliees, on refuse d'ajouter le conducteur
-	if (deja_liees) return(false);
-	
-	// sinon on ajoute le conducteur
-	conductors_.append(f);
+		//Check if this terminal isn't already linked with other_terminal
+	foreach (Conductor* cond, conductors_)
+		if (cond -> terminal1 == other_terminal || cond -> terminal2 == other_terminal)
+			return false; //They already a conductor linked to this and other_terminal
+
+	conductors_.append(conductor);
+	emit conductorWasAdded(conductor);
 	return(true);
 }
 
 /**
-	Enleve un conducteur donne a la borne
-	@param f Conducteur a enlever
-*/
-void Terminal::removeConductor(Conductor *f) {
-	int index = conductors_.indexOf(f);
+ * @brief Terminal::removeConductor
+ * Remove a conductor from this terminal
+ * @param conductor : conductor to remove
+ */
+void Terminal::removeConductor(Conductor *conductor)
+{
+	int index = conductors_.indexOf(conductor);
 	if (index == -1) return;
 	conductors_.removeAt(index);
+	emit conductorWasRemoved(conductor);
 }
 
 /**
@@ -222,32 +221,12 @@ void Terminal::removeConductor(Conductor *f) {
 	@param options Les options de dessin
 	@param widget Le widget sur lequel on dessine
 */
-void Terminal::paint(QPainter *p, const QStyleOptionGraphicsItem *options, QWidget *widget) {
+void Terminal::paint(QPainter *p, const QStyleOptionGraphicsItem *options, QWidget *) {
 	// en dessous d'un certain zoom, les bornes ne sont plus dessinees
 	if (options && options -> levelOfDetail < 0.5) return;
 	
 	p -> save();
-	
-#ifndef Q_WS_WIN
-	// corrige un bug de rendu ne se produisant que lors du rendu sur QGraphicsScene sous X11 au zoom par defaut
-	static bool must_correct_rendering_bug = QETApp::settings().value("correct-rendering", false).toBool();
-	if (must_correct_rendering_bug) {
-		Diagram *dia = diagram();
-		if (dia && options -> levelOfDetail == 1.0 && widget) {
-			// calcule la rotation qu'a subi l'element
-			qreal applied_rotation = 0.0;
-			if (Element *elt = qgraphicsitem_cast<Element *>(parentItem())) {
-				// orientations actuelle et par defaut de l'element
-				int ori_cur = elt -> orientation();
-				applied_rotation = QET::correctAngle(90.0 * ori_cur);
-			}
-			if (applied_rotation == 90.0) p -> translate(1.0, -1.0);
-			else if (applied_rotation == 180.0) p -> translate(-1.0, -1.0);
-			else if (applied_rotation == 270.0) p -> translate(-1.0, 1.0);
-		}
-	}
-#endif
-	
+
 	//annulation des renderhints
 	p -> setRenderHint(QPainter::Antialiasing,          false);
 	p -> setRenderHint(QPainter::TextAntialiasing,      false);
@@ -314,11 +293,11 @@ void Terminal::paint(QPainter *p, const QStyleOptionGraphicsItem *options, QWidg
 		{
 			m_help_line_a = new QGraphicsLineItem(this);
 			QPen pen;
-			pen.setColor(Qt::darkGray);
+			pen.setColor(Diagram::background_color == Qt::darkGray ? Qt::lightGray : Qt::darkGray);
 			m_help_line_a -> setPen(pen);
 		}
 
-		QRectF rect = diagram() -> drawingRect();
+		QRectF rect = diagram() -> border_and_titleblock.insideBorderRect();
 		QLineF line;
 
 		if (Qet::isHorizontal(orientation()))
@@ -376,7 +355,7 @@ void Terminal::drawHelpLine(bool draw)
 QLineF Terminal::HelpLine() const
 {
 	QPointF scene_dock = dockConductor();
-	QRectF  rect       = diagram() -> drawingRect();
+	QRectF  rect       = diagram() -> border_and_titleblock.insideBorderRect();
 
 	QLineF line(scene_dock , QPointF());
 
@@ -582,47 +561,67 @@ void Terminal::mouseReleaseEvent(QGraphicsSceneMouseEvent *e)
 	previous_terminal_ = 0;
 	hovered_color_     = neutralColor;
 
-	if (Diagram *d = diagram())
+	if (!diagram()) return;
+
+		//Stop conductor preview
+	diagram() -> setConductor(false);
+
+		//Get item under cursor
+	QGraphicsItem *qgi = diagram() -> itemAt(e -> scenePos(), QTransform());
+	if (!qgi) return;
+
+		//Element must be a terminal
+	Terminal *other_terminal = qgraphicsitem_cast<Terminal *>(qgi);
+	if (!other_terminal) return;
+
+	other_terminal -> hovered_color_ = neutralColor;
+	other_terminal -> hovered_       = false;
+
+		//We stop her if we can't link this terminal with other terminal
+	if (!canBeLinkedTo(other_terminal)) return;
+
+		//Create conductor
+	Conductor *new_conductor = new Conductor(this, other_terminal);
+
+		//Get all conductors at the same potential of new conductors
+	QSet <Conductor *> conductors_list = new_conductor->relatedPotentialConductors();
+
+		//Compare the properties of every conductors stored in conductors_list,
+		//if every conductors properties is equal, we use this properties for the new conductor.
+	ConductorProperties others_properties;
+	bool use_properties = false;
+	if (!conductors_list.isEmpty())
 	{
-			//Stop conductor preview
-		d -> setConductor(false);
-
-			//Get item under cursor
-		QGraphicsItem *qgi = d -> itemAt(e -> scenePos());
-		if (!qgi) return;
-
-			//Element must be a terminal
-		Terminal *other_terminal = qgraphicsitem_cast<Terminal *>(qgi);
-		if (!other_terminal) return;
-
-		other_terminal -> hovered_color_ = neutralColor;
-		other_terminal -> hovered_       = false;
-
-			//We stop her if we can't link this terminal with other terminal
-		if (!canBeLinkedTo(other_terminal)) return;
-
-			//Create conductor
-		Conductor *new_conductor = new Conductor(this, other_terminal);
-		new_conductor -> setProperties(d -> defaultConductorProperties);
-		QUndoCommand *undo = new AddItemCommand<Conductor *>(new_conductor, d);
-			//Autonum it
-		ConductorAutoNumerotation can (new_conductor, d, undo);
-		can.numerate();
-			//Add undo command to the parent diagram
-		d -> undoStack().push(undo);
+		use_properties = true;
+		others_properties = (*conductors_list.begin())->properties();
+		foreach (Conductor *conductor, conductors_list)
+			if (conductor->properties() != others_properties)
+				use_properties = false;
 	}
+
+
+	QUndoCommand *undo = new AddItemCommand<Conductor *>(new_conductor, diagram());
+
+	if (use_properties)
+		new_conductor->setProperties(others_properties);
+	else
+	{
+			//Autonum it
+		ConductorAutoNumerotation can (new_conductor, diagram(), undo);
+		can.numerate();
+	}
+
+		//Add undo command to the parent diagram
+	diagram() -> undoStack().push(undo);
 }
 
 /**
-	Met a jour l'eventuel conducteur relie a la borne.
-	@param newpos Position de l'element parent a prendre en compte
-*/
+ * @brief Terminal::updateConductor
+ * Update the path of conductor docked to this terminal
+ */
 void Terminal::updateConductor() {
-	if (!scene() || !parentItem()) return;
-	foreach (Conductor *conductor, conductors_) {
-		if (conductor -> isDestroyed()) continue;
-		conductor -> updatePath();
-	}
+	foreach (Conductor *conductor, conductors_)
+		conductor->updatePath();
 }
 
 /**
