@@ -22,6 +22,7 @@
 namespace QET {
 	namespace Icons {
 		QIcon Add;
+		QIcon AddFolio;
 		QIcon Allowed;
 		QIcon ApplicationExit;
 		QIcon ArrowLeft;
@@ -35,16 +36,18 @@ namespace QET {
 		QIcon ConductorSettings;
 		QIcon Configure;
 		QIcon ConfigureToolbars;
-		QIcon CopyFile;
+		QIcon IC_CopyFile;
 		QIcon DefaultConductor;
 		QIcon DiagramAdd;
 		QIcon Diagram;
-		QIcon DiagramDelete;
+        QIcon DiagramBg;
+        QIcon DiagramDelete;
 		QIcon DialogCancel;
 		QIcon DialogInformation;
 		QIcon DialogOk;
 		QIcon DocumentClose;
 		QIcon DocumentExport;
+		QIcon DocumentSpreadsheet;
 		QIcon DocumentImport;
 		QIcon DocumentNew;
 		QIcon DocumentOpen;
@@ -99,7 +102,7 @@ namespace QET {
 		QIcon HotSpot;
 		QIcon InsertImage;
 		QIcon Lower;
-		QIcon MoveFile;
+		QIcon IC_MoveFile;
 		QIcon Names;
 		QIcon Neutral;
 		QIcon NewDiagram;
@@ -125,7 +128,11 @@ namespace QET {
 		QIcon PrintPortrait;
 		QIcon PrintTwoPages;
 		QIcon Project;
+		QIcon ProjectClose;
+		QIcon ProjectNew;
+		QIcon Projects;
 		QIcon ProjectFile;
+		QIcon ProjectFileGP;
 		QIcon QETIcon;
 		QIcon QETLogo;
 		QIcon QETOxygenLogo;
@@ -188,6 +195,7 @@ void QET::Icons::initIcons() {
 	
 	Add                 .addFile(":/ico/16x16/list-add.png");
 	Add                 .addFile(":/ico/22x22/list-add.png");
+	AddFolio            .addFile(":/ico/16x16/folio-new.png");
 	Allowed             .addFile(":/ico/16x16/user-online.png");
 	ApplicationExit     .addFile(":/ico/16x16/application-exit.png");
 	ApplicationExit     .addFile(":/ico/22x22/application-exit.png");
@@ -208,11 +216,12 @@ void QET::Icons::initIcons() {
 	Configure           .addFile(":/ico/22x22/configure.png");
 	ConfigureToolbars   .addFile(":/ico/16x16/configure-toolbars.png");
 	ConfigureToolbars   .addFile(":/ico/22x22/configure-toolbars.png");
-	CopyFile            .addFile(":/ico/16x16/item_copy.png");
+	IC_CopyFile            .addFile(":/ico/16x16/item_copy.png");
 	DefaultConductor    .addFile(":/ico/22x22/conductor3.png");
 	DiagramAdd          .addFile(":/ico/22x22/diagram_add.png");
 	Diagram             .addFile(":/ico/diagram.png");
-	DiagramDelete       .addFile(":/ico/22x22/diagram_del.png");
+    DiagramBg           .addFile(":/ico/22x22/diagram_bg.png");
+    DiagramDelete       .addFile(":/ico/22x22/diagram_del.png");
 	DialogCancel        .addFile(":/ico/16x16/dialog-cancel.png");
 	DialogCancel        .addFile(":/ico/22x22/dialog-cancel.png");
 	DialogInformation   .addFile(":/ico/22x22/dialog-information.png");
@@ -222,6 +231,7 @@ void QET::Icons::initIcons() {
 	DocumentClose       .addFile(":/ico/22x22/document-close.png");
 	DocumentExport      .addFile(":/ico/16x16/document-export.png");
 	DocumentExport      .addFile(":/ico/22x22/document-export.png");
+	DocumentSpreadsheet .addFile(":/ico/22x22/qelectrotab-into.png");
 	DocumentExport      .addFile(":/ico/128x128/document-export.png");
 	DocumentImport      .addFile(":/ico/16x16/document-import.png");
 	DocumentImport      .addFile(":/ico/22x22/document-import.png");
@@ -234,7 +244,7 @@ void QET::Icons::initIcons() {
 	DocumentPrint       .addFile(":/ico/16x16/document-print.png");
 	DocumentPrint       .addFile(":/ico/22x22/document-print.png");
 	DocumentPrintFrame  .addFile(":/ico/16x16/document-print-frame.png");
-	DocumentPrintFrame  .addFile(":/ico/22x22/document-print-frame.png");
+	DocumentPrintFrame  .addFile(":/ico/48x48/document-print-frame.png");
 	DocumentSave        .addFile(":/ico/16x16/document-save.png");
 	DocumentSave        .addFile(":/ico/22x22/document-save.png");
 	DocumentSaveAll     .addFile(":/ico/16x16/document-save-all.png");
@@ -329,7 +339,7 @@ void QET::Icons::initIcons() {
 	HotSpot             .addFile(":/ico/22x22/hotspot.png");
 	InsertImage         .addFile(":/ico/22x22/insert-image.png");
 	Lower               .addFile(":/ico/22x22/lower.png");
-	MoveFile            .addFile(":/ico/16x16/item_move.png");
+	IC_MoveFile         .addFile(":/ico/16x16/item_move.png");
 	Names               .addFile(":/ico/22x22/names.png");
 	Neutral             .addFile(":/ico/16x16/neutral.png");
 	NewDiagram          .addFile(":/ico/128x128/diagram.png");
@@ -355,10 +365,16 @@ void QET::Icons::initIcons() {
 	PrintLandscape      .addFile(":/ico/22x22/landscape.png");
 	PrintPortrait       .addFile(":/ico/22x22/portrait.png");
 	PrintTwoPages       .addFile(":/ico/22x22/two_pages.png");
+	Projects            .addFile(":/ico/128x128/project.png");
+	ProjectClose        .addFile(":/ico/16x16/project-WH-close.png");
+	ProjectClose        .addFile(":/ico/22x22/project-WH-close.png");
+	ProjectNew          .addFile(":/ico/16x16/project-WH-new.png");
+	ProjectNew          .addFile(":/ico/22x22/project-WH-new.png");
 	ProjectFile         .addFile(":/ico/oxygen-icons/16x16/mimetypes/application-x-qet-project.png");
 	ProjectFile         .addFile(":/ico/oxygen-icons/22x22/mimetypes/application-x-qet-project.png");
 	ProjectFile         .addFile(":/ico/oxygen-icons/32x32/mimetypes/application-x-qet-project.png");
 	QETIcon             .addFile(":/ico/256x256/qelectrotech.png");
+	ProjectFileGP       .addFile(":/ico/16x16/project-WH.png");
 	QETLogo             .addFile(":/ico/16x16/qet.png");
 	QETLogo             .addFile(":/ico/256x256/qet.png");
 	QETOxygenLogo       .addFile(":/ico/oxygen-icons/128x128/apps/qelectrotech.png");
