@@ -31,6 +31,9 @@
 #include "ui/dialogwaiting.h"
 #include "numerotationcontext.h"
 #include "reportproperties.h"
+#include "integrationmovetemplateshandler.h"
+
+#include <QStandardPaths>
 
 QString QETProject::integration_category_name = "import";
 
@@ -71,10 +74,11 @@ QETProject::QETProject(int diagrams, QObject *parent) :
 }
 
 /**
-	Construit un projet a partir du chemin d'un fichier.
-	@param path Chemin du fichier
-	@param parent QObject parent
-*/
+ * @brief QETProject::QETProject
+ * Construct a project from a .qet file
+ * @param path : path of the file
+ * @param parent : parent QObject
+ */
 QETProject::QETProject(const QString &path, QObject *parent) :
 	QObject              (parent),
 	collection_          (0     ),
@@ -85,23 +89,25 @@ QETProject::QETProject(const QString &path, QObject *parent) :
 	folioSheetsQuantity  (0     ),
 	m_auto_conductor     (true  )
 {
-	// ouvre le fichier
+		//Open the file
 	QFile project_file(path);
-	if (!project_file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+	if (!project_file.open(QIODevice::ReadOnly | QIODevice::Text))
+	{
 		state_ = FileOpenFailed;
 		return;
 	}
 	setFilePath(path);
 	
-	// en extrait le contenu XML
-	bool xml_parsing = document_root_.setContent(&project_file);
-	if (!xml_parsing) {
+		//Extract the content of the xml
+	QDomDocument xml_project;
+	if (!xml_project.setContent(&project_file))
+	{
 		state_ = XmlParsingFailed;
 		return;
 	}
-	
-	// et construit le projet
-	readProjectXml();
+
+		//Build the project from the xml
+	readProjectXml(xml_project);
 	
 	setupTitleBlockTemplatesCollection();
 	
@@ -116,54 +122,36 @@ QETProject::QETProject(const QString &path, QObject *parent) :
 }
 
 /**
-	Construit un projet a partir d'un element XML representant le projet.
-	L'element XML fourni est copie et conserve dans la classe.
-*/
-QETProject::QETProject(const QDomElement &xml_element, QObject *parent) :
-	QObject              (parent),
-	collection_          (0     ),
-	project_qet_version_ (-1    ),
-	modified_            (false ),
-	read_only_           (false ),
-	titleblocks_         (this  ),
-	folioSheetsQuantity  (0     ),
-	m_auto_conductor     (true  )
+ * @brief QETProject::~QETProject
+ * Destructor
+ */
+QETProject::~QETProject()
 {
-	// copie le contenu XML
-	document_root_.appendChild(document_root_.importNode(xml_element, true));
-	
-	// et construit le projet
-	readProjectXml();
-	
-	setupTitleBlockTemplatesCollection();
-
-	undo_stack_ = new QUndoStack();
-	connect(undo_stack_, SIGNAL(cleanChanged(bool)), this, SLOT(undoStackChanged(bool)));
+	if (collection_) delete collection_;
+	qDeleteAll(diagrams_);
+	delete undo_stack_;
 }
 
 /**
-	Destructeur
-*/
-QETProject::~QETProject() {
-	// supprime les schemas
-	// qDebug() << "Suppression du projet" << ((void *)this);
-	
-	// supprime la collection
-	// qDebug() << "Suppression de la collection du projet" << ((void *)this);
-	if (collection_) {
-		delete collection_;
-	}
-	// qDebug() << "Collection du projet" << ((void *)this) << "supprimee";
-	
-	// qDebug() << diagrams_;
-	foreach (Diagram *diagram, diagrams_) {
-		diagrams_.removeAll(diagram);
-		delete diagram;
-	}
+ * @brief QETProject::integrateElementToProject
+ * Return true if we must to integarte the element to the project otherwise false
+ * @param location : element location
+ * @param project : project to test
+ * @return
+ */
+bool QETProject::integrateElementToProject(const ElementsLocation &location, const QETProject *project)
+{
+		//Integration element must be enable
+	QSettings settings;
+	bool auto_integration_enabled = settings.value("diagrameditor/integrate-elements", true).toBool();
 
-	folioSheetsQuantity = 0;
-	// qDebug() << diagrams_;
-	delete undo_stack_;
+		//the element belongs there a project and if so, is this another project of the project given by parameter?
+	bool elmt_from_project = location.project();
+	bool elmt_from_another_project = elmt_from_project && location.project() != project;
+
+	bool must_integrate_element = (elmt_from_another_project || (auto_integration_enabled && !elmt_from_project));
+
+	return(must_integrate_element);
 }
 
 /**
@@ -255,7 +243,7 @@ void QETProject::setFilePath(const QString &filepath) {
 QString QETProject::currentDir() const {
 	QString current_directory;
 	if (file_path_.isEmpty()) {
-		current_directory = QDesktopServices::storageLocation(QDesktopServices::DesktopLocation);
+		current_directory = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
 	} else {
 		current_directory = QFileInfo(file_path_).absoluteDir().absolutePath();
 	}
@@ -277,7 +265,7 @@ QString QETProject::pathNameTitle() const {
 	if (!project_title_.isEmpty()) {
 		final_title = QString(
 			tr(
-				"Projet \253\240%1\240\273",
+				"Projet « %1 »",
 				"displayed title for a ProjectView - %1 is the project title"
 			)
 		).arg(project_title_);
@@ -308,7 +296,7 @@ QString QETProject::pathNameTitle() const {
 	if (modified_) {
 		final_title = QString(
 			tr(
-				"%1 [modifi\351]",
+				"%1 [modifié]",
 				"displayed title for a modified project - %1 is a displayable title"
 			)
 		).arg(final_title);
@@ -349,53 +337,6 @@ void QETProject::setTitle(const QString &title) {
 	updateDiagramsFolioData();
 }
 
-/**
-	@return the list of the titleblock templates embedded within this project 
-*/
-QList<QString> QETProject::embeddedTitleBlockTemplates() {
-	return(titleblocks_.templates());
-}
-
-/**
-	@param template_name Name of the requested template
-	@return the requested template, or 0 if there is no valid template of this
-	name within the project
-*/
-const TitleBlockTemplate *QETProject::getTemplateByName(const QString &template_name) {
-	return(titleblocks_.getTemplate(template_name));
-}
-
-/**
-	@param template_name Name of the requested template
-	@return the XML description of the requested template, or a null QDomElement
-	if the project does not have such an titleblock template
-*/
-QDomElement QETProject::getTemplateXmlDescriptionByName(const QString &template_name) {
-	return(titleblocks_.getTemplateXmlDescription(template_name));
-}
-
-/**
-	This methods allows adding or modifying a template embedded within the
-	project.
-	@param template_name Name / Identifier of the template - will be used to
-	determine whether the given description will be added or will replace an
-	existing one.
-	@param xml_elmt An \<titleblocktemplate\> XML element describing the
-	template. Its "name" attribute must equal to template_name.
-	@return false if a problem occured, true otherwise
-*/
-bool QETProject::setTemplateXmlDescription(const QString &template_name, const QDomElement &xml_elmt) {
-	return(titleblocks_.setTemplateXmlDescription(template_name, xml_elmt));
-}
-
-/**
-	This methods allows removing a template embedded within the project.
-	@param template_name Name of the template to be removed
-*/
-void QETProject::removeTemplateByName(const QString &template_name) {
-	return(titleblocks_.removeTemplate(template_name));
-}
-
 /**
 	@return les dimensions par defaut utilisees lors de la creation d'un
 	nouveau schema dans ce projet.
@@ -422,12 +363,34 @@ TitleBlockProperties QETProject::defaultTitleBlockProperties() const {
 }
 
 /**
-	Permet de specifier le cartouche par defaut utilise lors de la creation
-	d'un nouveau schema dans ce projet.
-	@param titleblock Cartouche d'un schema
-*/
+ * @brief QETProject::setDefaultTitleBlockProperties
+ * Specify the title block to be used at the creation of a new diagram for this project
+ * @param titleblock
+ */
 void QETProject::setDefaultTitleBlockProperties(const TitleBlockProperties &titleblock) {
 	default_titleblock_properties_ = titleblock;
+		//Integrate the title block in this project
+	if (!titleblock.template_name.isEmpty())
+	{
+		TitleBlockTemplatesFilesCollection *collection = nullptr;
+		switch (titleblock.collection)
+		{
+			case QET::Common :
+				collection = QETApp::commonTitleBlockTemplatesCollection();
+				break;
+			case QET::Custom :
+				collection = QETApp::customTitleBlockTemplatesCollection();
+				break;
+			case QET::Embedded :
+				//Titleblock is already embedded to project
+				return;
+			default:
+				return;
+		}
+
+		QScopedPointer<IntegrationMoveTitleBlockTemplatesHandler> m(new IntegrationMoveTitleBlockTemplatesHandler);
+		integrateTitleBlockTemplate(collection -> location(titleblock.template_name), m.data());
+	}
 }
 
 /**
@@ -460,12 +423,9 @@ void QETProject::setDefaultXRefProperties(const QString type, const XRefProperti
 	emit XRefPropertiesChanged();
 }
 
-void QETProject::setDefaultXRefProperties(QHash<QString, XRefProperties> hash) {
-#if QT_VERSION >= 0x040800
+void QETProject::setDefaultXRefProperties(QHash<QString, XRefProperties> hash)
+{
 	m_default_xref_properties.swap(hash);
-#else
-	m_default_xref_properties = hash;
-#endif
 	emit XRefPropertiesChanged();
 }
 
@@ -573,7 +533,7 @@ QDomDocument QETProject::toXml() {
 		// Write the diagram to XML only if it is not of type DiagramFolioList.
 		DiagramFolioList *ptr = dynamic_cast<DiagramFolioList *>(diagram);
 		if ( !ptr ) {
-			qDebug() << qPrintable(QString("QETProject::toXml() : exporting diagram \"%1\" [%2]").arg(diagram -> title()).arg(QET::pointerString(diagram)));
+			qDebug() << qPrintable(QString("QETProject::toXml() : exporting diagram \"%1\"").arg(diagram -> title())) << "[" << diagram << "]";
 			QDomNode appended_diagram = project_root.appendChild(diagram -> writeXml(xml_doc));
 			appended_diagram.toElement().setAttribute("order", order_num ++);
 		}
@@ -593,32 +553,28 @@ bool QETProject::close() {
 }
 
 /**
-	Enregistre le projet vers un fichier.
-	@see filePath()
-	@see setFilePath()
-	@return true si l'enregistrement a reussi, false sinon
-*/
-QETResult QETProject::write() {
-	// this operation requires a filepath
-	if (file_path_.isEmpty()) {
+ * @brief QETProject::write
+ * Save the project in a file
+ * @see filePath()
+ * @see setFilePath()
+ * @return true if the project was successfully saved, else false
+ */
+QETResult QETProject::write()
+{
+		// this operation requires a filepath
+	if (file_path_.isEmpty())
 		return(QString("unable to save project to file: no filepath was specified"));
-	}
 
-	// if the project was opened read-only and the file is still non-writable, do not save the project
-	if (isReadOnly() && !QFileInfo(file_path_).isWritable()) {
+		// if the project was opened read-only and the file is still non-writable, do not save the project
+	if (isReadOnly() && !QFileInfo(file_path_).isWritable())
 		return(QString("the file %1 was opened read-only and thus will not be written").arg(file_path_));
-	}
-
-	// realise l'export en XML du projet dans le document XML interne
-	document_root_.clear();
-	document_root_.appendChild(document_root_.importNode(toXml().documentElement(), true));
 
+		//Get the project in xml
+	QDomDocument xml_project;
+	xml_project.appendChild(xml_project.importNode(toXml().documentElement(), true));
 
 	QString error_message;
-	bool writing = QET::writeXmlFile(document_root_, file_path_, &error_message);
-	if (!writing) {
-		return(error_message);
-	}
+	if (!QET::writeXmlFile(xml_project, file_path_, &error_message)) return(error_message);
 
 	setModified(false);
 	return(QETResult());
@@ -738,7 +694,7 @@ QString QETProject::integrateElement(const QString &elmt_location, QString &erro
 QString QETProject::integrateElement(const QString &elmt_path, MoveElementsHandler *handler, QString &error_message) {
 	// on s'assure que le projet a une categorie dediee aux elements importes automatiquement
 	if (!ensureIntegrationCategoryExists()) {
-		error_message = tr("Impossible de cr\351er la cat\351gorie pour l'int\351gration des \351l\351ments");
+		error_message = tr("Impossible de créer la catégorie pour l'intégration des éléments");
 		return(QString());
 	}
 	
@@ -749,7 +705,7 @@ QString QETProject::integrateElement(const QString &elmt_path, MoveElementsHandl
 	ElementsCollectionItem *integ_item = QETApp::collectionItem(ElementsLocation::locationFromString(elmt_path));
 	ElementDefinition *integ_elmt = integ_item ? integ_item -> toElement() : 0;
 	if (!integ_item || !integ_elmt) {
-		error_message = tr("Impossible d'acc\351der \340 l'\351l\351ment \340 int\351grer");
+		error_message = tr("Impossible d'accéder à l'élément à intégrer");
 		return(QString());
 	}
 	
@@ -766,7 +722,7 @@ QString QETProject::integrateElement(const QString &elmt_path, MoveElementsHandl
 			// la categorie cible n'existe pas : on la cree par recopie
 			ElementsCollectionItem *result_cat = par_cat -> copy(target_cat, handler, false);
 			if (!result_cat || !result_cat -> isCategory()) {
-				error_message = QString(tr("Un probl\350me s'est produit pendant la copie de la cat\351gorie %1")).arg(par_cat -> location().toString());
+				error_message = QString(tr("Un problème s'est produit pendant la copie de la catégorie %1")).arg(par_cat -> location().toString());
 				return(QString());
 			}
 			target_cat = result_cat -> toCategory();
@@ -820,7 +776,8 @@ QString QETProject::integrateTitleBlockTemplate(const TitleBlockTemplateLocation
 	
 	// check whether a TBT having the same name already exists within this project
 	QString target_name = dst_tbt.name();
-	while (titleblocks_.templates().contains(target_name)) {
+	while (titleblocks_.templates().contains(target_name))
+	{
 		QET::Action action = handler -> templateAlreadyExists(src_tbt, dst_tbt);
 		if (action == QET::Retry) {
 			continue;
@@ -835,12 +792,9 @@ QString QETProject::integrateTitleBlockTemplate(const TitleBlockTemplateLocation
 		}
 	}
 	
-	bool integration = setTemplateXmlDescription(
-		target_name,
-		src_tbt.getTemplateXmlDescription()
-	);
-	if (!integration) {
-		handler -> errorWithATemplate(src_tbt, tr("Une erreur s'est produite durant l'int\351gration du mod\350le.", "error message"));
+	if (!titleblocks_.setTemplateXmlDescription(target_name, src_tbt.getTemplateXmlDescription()))
+	{
+		handler -> errorWithATemplate(src_tbt, tr("Une erreur s'est produite durant l'intégration du modèle.", "error message"));
 		target_name = QString();
 	}
 	return(target_name);
@@ -878,13 +832,6 @@ bool QETProject::usesTitleBlockTemplate(const TitleBlockTemplateLocation &locati
 	return(false);
 }
 
-/**
-	Delete all title block templates not used in the project
-*/
-void QETProject::cleanUnusedTitleBlocKTemplates() {
-	titleblocks_.deleteUnusedTitleBlocKTemplates();
-}
-
 /**
 	Supprime tous les elements inutilises dans le projet
 	@param handler Gestionnaire d'erreur
@@ -961,7 +908,7 @@ QList <Diagram *> QETProject::addNewDiagramFolioList() {
 			diagram_folio_list -> border_and_titleblock.importTitleBlock(defaultTitleBlockProperties());
 			diagram_folio_list -> defaultConductorProperties = defaultConductorProperties();
 
-			diagram_folio_list -> border_and_titleblock.setTitle(tr("Liste des Sch\351mas"));
+            diagram_folio_list -> border_and_titleblock.setTitle(tr("Liste des Folios"));
 			// no need to display rows and columns
 			diagram_folio_list -> border_and_titleblock.displayRows(false);
 			diagram_folio_list -> border_and_titleblock.displayColumns(false);
@@ -1055,158 +1002,230 @@ ElementsCategory *QETProject::rootCategory() const {
 }
 
 /**
-	(Re)lit le projet depuis sa description XML
-*/
-void QETProject::readProjectXml() {
-	QDomElement root_elmt = document_root_.documentElement();
+ * @brief QETProject::readProjectXml
+ * Read and make the project from an xml description
+ * @param xml_project : the description of the project from an xml
+ */
+void QETProject::readProjectXml(QDomDocument &xml_project)
+{
+	QDomElement root_elmt = xml_project.documentElement();
 	state_ = ProjectParsingRunning;
 	
-	// la racine du document XML est sensee etre un element "project"
-	if (root_elmt.tagName() == "project") {
-
-		// mode d'ouverture normal
-		if (root_elmt.hasAttribute("version")) {
+		//The roots of the xml document must be a "project" element
+	if (root_elmt.tagName() == "project")
+	{
+			//Normal opening mode
+		if (root_elmt.hasAttribute("version"))
+		{
 			bool conv_ok;
 			project_qet_version_ = root_elmt.attribute("version").toDouble(&conv_ok);
-			if (conv_ok && QET::version.toDouble() < project_qet_version_) {
+
+			if (conv_ok && QET::version.toDouble() < project_qet_version_)
+			{
+				int ret = QET::QetMessageBox::warning(
+							  0,
+							  tr("Avertissement", "message box title"),
+							  tr(
+								  "Ce document semble avoir été enregistré avec "
+								  "une version ultérieure de QElectroTech. Il est "
+								  "possible que l'ouverture de tout ou partie de ce "
+								  "document échoue.\n"
+								  "Que désirez vous faire ?",
+								  "message box content"
+								  ),
+							  QMessageBox::Open | QMessageBox::Cancel
+							  );
 				
-				int ret = QET::MessageBox::warning(
-					0,
-					tr("Avertissement", "message box title"),
-					tr(
-						"Ce document semble avoir \351t\351 enregistr\351 avec "
-						"une version ult\351rieure de QElectroTech. Il est "
-						"possible que l'ouverture de tout ou partie de ce "
-						"document \351choue.\n"
-						"Que d\351sirez vous faire ?",
-						"message box content"
-					),
-					QMessageBox::Open | QMessageBox::Cancel
-				);
-				
-				if (ret == QMessageBox::Cancel) {
+				if (ret == QMessageBox::Cancel)
+				{
 					state_ = FileOpenDiscard;
 					return;
 				}
-				
 			}
 		}
-		
 		setTitle(root_elmt.attribute("title"));
-	} else {
+	}
+	else
+	{
 		state_ = ProjectParsingFailed;
 	}
 	
-	// load the project-wide properties
-	readProjectPropertiesXml();
-	
-	// charge les proprietes par defaut pour les nouveaux schemas
-	readDefaultPropertiesXml();
-	
-	// load the embedded titleblock templates
-	readEmbeddedTemplatesXml();
-	
-	// charge la collection embarquee
-	readElementsCollectionXml();
-	
-	// charge les schemas
-	readDiagramsXml();
+		//Load the project-wide properties
+	readProjectPropertiesXml(xml_project);
+		//Load the default properties for the new diagrams
+	readDefaultPropertiesXml(xml_project);
+		//load the embedded titleblock templates
+	titleblocks_.fromXml(xml_project.documentElement());
+		//Load the embedded elements collection
+	readElementsCollectionXml(xml_project);
+		//Load the diagrams
+	readDiagramsXml(xml_project);
 
-	// if there is an attribute for folioSheetQuantity, then set it accordingly.
-	// If not, then the value remains at the initial value of zero.
-	if (root_elmt.attribute("folioSheetQuantity","0").toInt()) {
+		// if there is an attribute for folioSheetQuantity, then set it accordingly.
+		// If not, then the value remains at the initial value of zero.
+	if (root_elmt.attribute("folioSheetQuantity","0").toInt())
 		addNewDiagramFolioList();
-	}
 	
 	state_ = Ok;
 }
 
 /**
-	Charge les schemas depuis la description XML du projet.
-	A noter qu'un projet peut parfaitement ne pas avoir de schema.
-*/
-void QETProject::readDiagramsXml() {
-	// map destinee a accueillir les schemas
+ * @brief QETProject::readDiagramsXml
+ * Load the diagrams from the xml description of the project.
+ * Note a project can have 0 diagram
+ * @param xml_project
+ */
+void QETProject::readDiagramsXml(QDomDocument &xml_project)
+{
 	QMultiMap<int, Diagram *> loaded_diagrams;
 	
+	//@TODO try to solve a weird bug (dialog is black) since port to Qt5 with the DialogWaiting
 	//show DialogWaiting
 	DialogWaiting* dlgWaiting = new DialogWaiting();
 	dlgWaiting -> setModal(true);
 	dlgWaiting -> show();
 	dlgWaiting -> setTitle( tr("<b>Ouverture du projet en cours...</b>") );
 	
-	// recherche les schemas dans le projet
-	QDomNodeList diagram_nodes = document_root_.elementsByTagName("diagram");
+		//Search the diagrams in the project
+	QDomNodeList diagram_nodes = xml_project.elementsByTagName("diagram");
 	dlgWaiting->setProgressBarRange(0, diagram_nodes.length());
-	for (uint i = 0 ; i < diagram_nodes.length() ; ++ i) {
+	for (int i = 0 ; i < diagram_nodes.length() ; ++ i)
+	{
 		dlgWaiting->setProgressBar(i+1);
-		if (diagram_nodes.at(i).isElement()) {
+		if (diagram_nodes.at(i).isElement())
+		{
 			QDomElement diagram_xml_element = diagram_nodes.at(i).toElement();
 			Diagram *diagram = new Diagram(this);
 			bool diagram_loading = diagram -> initFromXml(diagram_xml_element);
-			if (diagram_loading) {
+			if (diagram_loading)
+			{
 				dlgWaiting->setDetail( diagram->title() );
-				// recupere l'attribut order du schema
+					//Get the attribute "order" of the diagram
 				int diagram_order = -1;
 				if (!QET::attributeIsAnInteger(diagram_xml_element, "order", &diagram_order)) diagram_order = 500000;
 				loaded_diagrams.insert(diagram_order, diagram);
-			} else {
+			}
+			else
+			{
 				delete diagram;
 			}
 		}
 	}
 	
-	// ajoute les schemas dans l'ordre indique par les attributs order
-	foreach(Diagram *diagram, loaded_diagrams.values()) {
+		//Add the diagrams according to there "order" attribute
+	foreach(Diagram *diagram, loaded_diagrams.values())
 		addDiagram(diagram);
-	}
-	// Initialise links between elements in this project
-	foreach (Diagram *d, diagrams()) {
+
+		//Initialise links between elements in this project
+	foreach (Diagram *d, diagrams())
 		d->initElementsLinks();
-	}
 
-
-	//delete dialog object
 	delete dlgWaiting;
 }
 
 /**
-	Loads the embedded template from the XML description of the project
-*/
-void QETProject::readEmbeddedTemplatesXml() {
-	titleblocks_.fromXml(document_root_.documentElement());
-}
-
-/**
-	Charge les schemas depuis la description XML du projet
-*/
-void QETProject::readElementsCollectionXml() {
-	// recupere la collection d'elements integreee au projet
-	QDomNodeList collection_roots = document_root_.elementsByTagName("collection");
+ * @brief QETProject::readElementsCollectionXml
+ * Load the diagrams from the xml description of the project
+ * @param xml_project : the xml description of the project
+ */
+void QETProject::readElementsCollectionXml(QDomDocument &xml_project)
+{
+		//Get the embedded elements collection of the project
+	QDomNodeList collection_roots = xml_project.elementsByTagName("collection");
 	QDomElement collection_root;
-	if (!collection_roots.isEmpty()) {
-		// seule la premiere collection trouvee est prise en compte
+
+	if (!collection_roots.isEmpty())
+	{
+			//Only the first found collection is take
 		collection_root = collection_roots.at(0).toElement();
 	}
 	
-	if (collection_root.isNull()) {
-		// s'il n'y en a pas, cree une collection vide
+	if (collection_root.isNull()) //Make an empty collection
 		collection_ = new XmlElementsCollection();
-	} else {
-		// sinon lit cette collection
+	else //Read the collection
 		collection_ = new XmlElementsCollection(collection_root);
-	}
+
 	collection_ -> setProtocol("embed");
 	collection_ -> setProject(this);
 	connect(collection_, SIGNAL(written()), this, SLOT(componentWritten()));
 }
 
 /**
-	Load project properties from the XML description of the project
-*/
-void QETProject::readProjectPropertiesXml() {
-	foreach (QDomElement e, QET::findInDomElement(document_root_.documentElement(), "properties")) {
+ * @brief QETProject::readProjectPropertiesXml
+ * Load project properties from the XML description of the project
+ * @param xml_project : the xml description of the project
+ */
+void QETProject::readProjectPropertiesXml(QDomDocument &xml_project)
+{
+	foreach (QDomElement e, QET::findInDomElement(xml_project.documentElement(), "properties"))
 		project_properties_.fromXml(e);
+}
+
+/**
+ * @brief QETProject::readDefaultPropertiesXml
+ * load default properties for new diagram, found in the xml of this project
+ * or by default find in the QElectroTech global conf
+ * @param xml_project : the xml description of the project
+ */
+void QETProject::readDefaultPropertiesXml(QDomDocument &xml_project)
+{
+		// Find xml element where is stored properties for new diagram
+	QDomNodeList newdiagrams_nodes = xml_project.elementsByTagName("newdiagrams");
+	if (newdiagrams_nodes.isEmpty()) return;
+
+	QDomElement newdiagrams_elmt = newdiagrams_nodes.at(0).toElement();
+
+		// By default, use value find in the global conf of QElectroTech
+	default_border_properties_	   = BorderProperties::    defaultProperties();
+	default_titleblock_properties_ = TitleBlockProperties::defaultProperties();
+	default_conductor_properties_  = ConductorProperties:: defaultProperties();
+	default_report_properties_	   = ReportProperties::    defaultProperties();
+	m_default_xref_properties	   = XRefProperties::      defaultProperties();
+
+		//Read values indicate in project
+	QDomElement border_elmt, titleblock_elmt, conductors_elmt, report_elmt, xref_elmt, conds_autonums;
+
+	for (QDomNode child = newdiagrams_elmt.firstChild() ; !child.isNull() ; child = child.nextSibling())
+	{
+		QDomElement child_elmt = child.toElement();
+		if (child_elmt.isNull()) continue;
+
+		if (child_elmt.tagName() == "border")
+			border_elmt = child_elmt;
+		else if (child_elmt.tagName() == "inset")
+			titleblock_elmt = child_elmt;
+		else if (child_elmt.tagName() == "conductors")
+			conductors_elmt = child_elmt;
+		else if (child_elmt.tagName() == "report")
+			report_elmt = child_elmt;
+		else if (child_elmt.tagName() == "xrefs")
+			xref_elmt = child_elmt;
+		else if (child_elmt.tagName() == "conductors_autonums")
+			conds_autonums = child_elmt;
+	}
+
+		// size, titleblock, conductor, report, conductor autonum
+	if (!border_elmt.isNull())	   default_border_properties_.fromXml(border_elmt);
+	if (!titleblock_elmt.isNull()) default_titleblock_properties_.fromXml(titleblock_elmt);
+	if (!conductors_elmt.isNull()) default_conductor_properties_.fromXml(conductors_elmt);
+	if (!report_elmt.isNull())	   setDefaultReportProperties(report_elmt.attribute("label"));
+	if (!xref_elmt.isNull())
+	{
+		foreach(QDomElement elmt, QET::findInDomElement(xref_elmt, "xref"))
+		{
+			XRefProperties xrp;
+			xrp.fromXml(elmt);
+			m_default_xref_properties.insert(elmt.attribute("type"), xrp);
+		}
+	}
+	if (!conds_autonums.isNull())
+	{
+		foreach (QDomElement elmt, QET::findInDomElement(conds_autonums, "conductor_autonum"))
+		{
+			NumerotationContext nc;
+			nc.fromXml(elmt);
+			m_conductor_autonum.insert(elmt.attribute("title"), nc);
+		}
 	}
 }
 
@@ -1217,68 +1236,6 @@ void QETProject::writeProjectPropertiesXml(QDomElement &xml_element) {
 	project_properties_.toXml(xml_element);
 }
 
-/**
- * @brief QETProject::readDefaultPropertiesXml
- * load default properties for new diagram, found in the xml of this project
- * or by default find in the QElectroTech global conf
- */
-void QETProject::readDefaultPropertiesXml() {
-	// Find xml element where is stored properties for new diagram
-	QDomNodeList newdiagrams_nodes = document_root_.elementsByTagName("newdiagrams");
-	if (newdiagrams_nodes.isEmpty()) return;
-	
-	QDomElement newdiagrams_elmt = newdiagrams_nodes.at(0).toElement();
-	
-	// By default, use value find in the global conf of QElectroTech
-	default_border_properties_	   = BorderProperties::    defaultProperties();
-	default_titleblock_properties_ = TitleBlockProperties::defaultProperties();
-	default_conductor_properties_  = ConductorProperties:: defaultProperties();
-	default_report_properties_	   = ReportProperties::    defaultProperties();
-	m_default_xref_properties	   = XRefProperties::      defaultProperties();
-	
-	//Read values indicate in project
-	QDomElement border_elmt, titleblock_elmt, conductors_elmt, report_elmt, xref_elmt, conds_autonums;
-	
-	for (QDomNode child = newdiagrams_elmt.firstChild() ; !child.isNull() ; child = child.nextSibling()) {
-		QDomElement child_elmt = child.toElement();
-		if (child_elmt.isNull()) continue;
-		if (child_elmt.tagName() == "border") {
-			border_elmt = child_elmt;
-		} else if (child_elmt.tagName() == "inset") {
-			titleblock_elmt = child_elmt;
-		} else if (child_elmt.tagName() == "conductors") {
-			conductors_elmt = child_elmt;
-		} else if (child_elmt.tagName() == "report") {
-			report_elmt = child_elmt;
-		} else if (child_elmt.tagName() == "xrefs") {
-			xref_elmt = child_elmt;
-		} else if (child_elmt.tagName() == "conductors_autonums") {
-			conds_autonums = child_elmt;
-		}
-	}
-	
-	// size, titleblock, conductor, report, conductor autonum
-	if (!border_elmt.isNull())	   default_border_properties_.fromXml(border_elmt);
-	if (!titleblock_elmt.isNull()) default_titleblock_properties_.fromXml(titleblock_elmt);
-	if (!conductors_elmt.isNull()) default_conductor_properties_.fromXml(conductors_elmt);
-	if (!report_elmt.isNull())	   setDefaultReportProperties(report_elmt.attribute("label"));
-	if (!xref_elmt.isNull()) {
-		foreach(QDomElement elmt, QET::findInDomElement(xref_elmt, "xref")) {
-			XRefProperties xrp;
-			xrp.fromXml(elmt);
-			m_default_xref_properties.insert(elmt.attribute("type"), xrp);
-		}
-	}
-	if (!conds_autonums.isNull()) {
-		foreach (QDomElement elmt, QET::findInDomElement(conds_autonums, "conductor_autonum")) {
-			NumerotationContext nc;
-			nc.fromXml(elmt);
-			m_conductor_autonum.insert(elmt.attribute("title"), nc);
-		}
-	}
-}
-
-
 /**
  * @brief QETProject::writeDefaultPropertiesXml
  * Export all defaults properties used by a new diagram and his content
@@ -1378,17 +1335,17 @@ NamesList QETProject::namesListForIntegrationCategory() {
 	const QChar russian_data[24] = { 0x0418, 0x043C, 0x043F, 0x043E, 0x0440, 0x0442, 0x0438, 0x0440, 0x043E, 0x0432, 0x0430, 0x043D, 0x043D, 0x044B, 0x0435, 0x0020, 0x044D, 0x043B, 0x0435, 0x043C, 0x0435, 0x043D, 0x0442, 0x044B };
 	const QChar greek_data[18] = { 0x0395, 0x03b9, 0x03c3, 0x03b7, 0x03b3, 0x03bc, 0x03ad, 0x03bd, 0x03b1, 0x0020, 0x03c3, 0x03c4, 0x03bf, 0x03b9, 0x03c7, 0x03b5, 0x03af, 0x03b1 };
 
-	names.addName("fr", "\311l\351ments import\351s");
+	names.addName("fr", "Éléments importés");
 	names.addName("en", "Imported elements");
 	names.addName("de", "Importierte elemente");
 	names.addName("es", "Elementos importados");
 	names.addName("ru", QString(russian_data, 24));
-	names.addName("cs", "Zaveden\351 prvky");
+	names.addName("cs", "Zavedené prvky");
 	names.addName("pl", "Elementy importowane");
 	names.addName("pt", "elementos importados");
 	names.addName("it", "Elementi importati");
 	names.addName("el", QString(greek_data, 18));
-	names.addName("nl", "Elementen ge\357mporteerd");
+	names.addName("nl", "Elementen geïmporteerd");
 	names.addName("hr", "Uvezeni elementi");
 	names.addName("ca", "Elements importats");
 	names.addName("ro", "Elemente importate");
@@ -1438,16 +1395,6 @@ bool QETProject::embeddedCollectionWasModified() {
 	return(false);
 }
 
-/**
-	@return true if the embedded title block templates collection was modified,
-	false otherwise.
-*/
-bool QETProject::titleBlockTemplateCollectionWasModified() {
-	// we do not expect a new project to embed any title block template (this may
-	// change in the future though).
-	return(titleblocks_.templates().count());
-}
-
 /**
 	@return the project-wide properties made available to child diagrams.
 */
@@ -1477,7 +1424,7 @@ bool QETProject::projectWasModified() {
 	if ( projectOptionsWereModified()    ||
 		 !undo_stack_ -> isClean()       ||
 		 embeddedCollectionWasModified() ||
-		 titleBlockTemplateCollectionWasModified() )
+		 titleblocks_.templates().count() )
 		return(true);
 	
 	else
@@ -1549,7 +1496,7 @@ ElementsLocation QETProject::copyElementWithHandler(
 	ElementsCollectionItem *result_item = integ_elmt -> copy(target_cat, handler);
 	ElementDefinition *result_elmt = result_item ? result_item -> toElement() : 0;
 	if (!result_item || !result_elmt) {
-		error_message = QString(tr("Un probl\350me s'est produit pendant la copie de l'\351l\351ment %1")).arg(integ_elmt -> location().toString());
+		error_message = QString(tr("Un problème s'est produit pendant la copie de l'élément %1")).arg(integ_elmt -> location().toString());
 		return(ElementsLocation());
 	}
 	return(result_elmt -> location());
