@@ -761,7 +761,7 @@ SplitCellsCommand::SplitCellsCommand(const TitleBlockTemplateCellsSet &splitted_
 	setText(
 		QString(
 			QObject::tr(
-				"S\351paration d'une cellule en %1",
+				"Séparation d'une cellule en %1",
 				"label used in the title block template editor undo list; %1 is the number of cells after the split"
 			)
 		).arg(spanned_cells_.count() + 1)
@@ -852,7 +852,7 @@ void SplitCellsCommand::redo() {
 	@param parent Parent QUndoCommand
 */
 ChangeTemplateInformationsCommand::ChangeTemplateInformationsCommand(TitleBlockTemplate *tbt, const QString &old_info, const QString &new_info, QUndoCommand *parent) :
-	QUndoCommand(QObject::tr("modification des informations compl\351mentaires", "undo caption"), parent),
+	QUndoCommand(QObject::tr("modification des informations complémentaires", "undo caption"), parent),
 	tbtemplate_(tbt),
 	old_information_(old_info),
 	new_information_(new_info)
