@@ -285,7 +285,7 @@ bool TitleBlockTemplate::loadLogo(const QDomElement &xml_element) {
 		QTextStream xml_to_byte_array(&logo_data);
 		svg_element.save(xml_to_byte_array, 0);
 	} else if (logo_storage == "base64") {
-		logo_data = QByteArray::fromBase64(xml_element.text().toAscii());
+		logo_data = QByteArray::fromBase64(xml_element.text().toLatin1());
 	} else {
 		return(false);
 	}
@@ -583,21 +583,6 @@ void TitleBlockTemplate::initCells() {
 #endif
 }
 
-/**
-	@return A string representing the titleblock template
-	@see TitleBlockCell::toString()
-*/
-QString TitleBlockTemplate::toString() const {
-	QString str = "\n";
-	for (int j = 0 ; j < rows_heights_.count() ; ++ j) {
-		for (int i = 0 ; i < columns_width_.count() ; ++ i) {
-			str += cells_[i][j] -> toString() + "    ";
-		}
-		str += "\n";
-	}
-	return(str);
-}
-
 /**
 	@return the name of this template
 */
@@ -1228,9 +1213,11 @@ void TitleBlockTemplate::render(QPainter &painter, const DiagramContext &diagram
 	QList<int> widths = columnsWidth(titleblock_width);
 	int titleblock_height = height();
 	
-	// prepare the QPainter
-	painter.setPen(Qt::black);
-	painter.setBrush(Qt::white);
+	painter.save();
+		//Setup the QPainter
+	QPen pen(Qt::black);
+	pen.setCosmetic(true);
+	painter.setPen(pen);
 	
 	// draw the titleblock border
 	painter.drawRect(QRect(0, 0, titleblock_width, titleblock_height));
@@ -1256,6 +1243,7 @@ void TitleBlockTemplate::render(QPainter &painter, const DiagramContext &diagram
 			renderCell(painter, *cells_[i][j], diagram_context, cell_rect);
 		}
 	}
+	painter.restore();
 }
 
 /**
@@ -1318,7 +1306,6 @@ void TitleBlockTemplate::renderCell(QPainter &painter, const TitleBlockCell &cel
 	QPen pen(QBrush(), 0.0, Qt::SolidLine, Qt::SquareCap, Qt::MiterJoin);
 	pen.setColor(Qt::black);
 	painter.setPen(pen);
-	painter.setBrush(Qt::white);
 	painter.drawRect(cell_rect);
 	
 	painter.save();
