@@ -24,7 +24,8 @@ namespace Ui {
 	class ElementInfoPartWidget;
 }
 
-class ElementInfoPartWidget : public QWidget {
+class ElementInfoPartWidget : public QWidget
+{
 	Q_OBJECT
 
 	//METHODS
@@ -38,6 +39,12 @@ class ElementInfoPartWidget : public QWidget {
 		bool    mustShow    () const;
 		void    setShow     (const bool &);
 		void    setHideShow (const bool &);
+		void    setFocusTolineEdit();
+
+	signals:
+		void textEdited  (const QString & text);
+		void textChanged (const QString & text);
+		void showClicked (bool checked);
 
 	//ATTRIBUTES
 	private:
